rem 
rem $Header: oci19.sql,v 1.1 1995/03/05 23:39:56 vraghuna Exp $ 
rem 
Rem  Copyright (c) 1995 by Oracle Corporation 
Rem    NAME
Rem      oci19.sql 
Rem    DESCRIPTION
Rem	 Script for A22400 OCI Techniques White Paper
Rem      Demo script for oci19.c
Rem    MODIFIED   (MM/DD/YY)
Rem     vraghuna   03/01/95 -  Creation
 
set echo on;
connect internal;
drop user ocitest cascade;
create user ocitest identified by ocitest;
grant connect,resource to ocitest;
connect ocitest/ocitest;

create table oci19tab (col1 varchar2(30) unique);
insert into oci19tab values ('AB');
insert into oci19tab values ('ABCDEFG');
insert into oci19tab values ('ABCDEFGHIJ');
insert into oci19tab values ('ABCDEFGHIJKLMNO');
commit;
