rem 
rem $Header: oci22.sql,v 1.1 1995/03/05 23:42:31 vraghuna Exp $ 
rem 
Rem  Copyright (c) 1995 by Oracle Corporation 
Rem    NAME
Rem      oci22.sql
Rem    DESCRIPTION
Rem	 Script for A22400 OCI Techniques White Paper
Rem      Demo script for oci22.c
Rem    MODIFIED   (MM/DD/YY)
Rem     vraghuna   03/01/95 -  Creation

set echo on;
connect internal;
drop user ocitest cascade;
create user ocitest identified by ocitest;
grant connect,resource to ocitest;
connect ocitest/ocitest;

create table oci22tab (col1 varchar2(30));
insert into oci22tab values ('A');
insert into oci22tab values ('AB');
insert into oci22tab values ('ABC');
insert into oci22tab values ('ABCD');
insert into oci22tab values ('ABCDE');
insert into oci22tab values ('ABCDEF');
insert into oci22tab values ('ABCDEFG');
insert into oci22tab values ('ABCDEFGH');
insert into oci22tab values ('ABCDEFGHI');
insert into oci22tab values ('ABCDEFGHIJ');
insert into oci22tab values ('ABCDEFGHIJK');
insert into oci22tab values ('ABCDEFGHIJKL');

commit;

