rem 
rem $Header: dbmsdfrd.sql,v 1.4 1994/03/29 14:41:56 adowning Exp $ 
rem 
Rem  Copyright (c) 1992 by Oracle Corporation 
Rem    NAME
Rem      dbmsdfrd.sql - dbms_defer_DUMMY
Rem    DESCRIPTION
Rem      This package is private.
Rem    RETURNS
Rem 
Rem    NOTES
Rem      <other useful comments, qualifications, etc.>
Rem    MODIFIED   (MM/DD/YY)
Rem     adowning   03/29/94 -  merge changes from branch 1.1.710.3
Rem     dsdaniel   01/18/94 -  merge changes from branch 1.1.710.2
Rem     adowning   02/02/94 -  split file into public / private binary files
Rem     dsdaniel   10/29/93 -  change to only dbms_defer_sys.execute
Rem     rjenkins   10/20/93 -  merge changes from branch 1.1.710.1
Rem     rjenkins   10/14/93 -  bringing into the mainline
Rem     rjenkins   09/30/93 -  Creation
Rem

rem   +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
