Rem 
Rem $Header: cat7303.sql 14-aug-96.17:42:30 lcprice Exp $
Rem
Rem cat7303.sql
Rem 
Rem  Copyright (c) Oracle Corporation 1996. All Rights Reserved.
Rem
Rem    NAME
Rem      cat7303.sql - 7.3.2 to 7.3.3 dictionary migrate script
Rem
Rem    DESCRIPTION
Rem
Rem    NOTES
Rem      RIGHT AFTER A 7.3.2 DATABASE IS STARTED UP USING 7.3.3
Rem      FOR THE FIRST TIME, RUN THIS SCRIPT ONCE AS INTERNAL.
Rem      A 7.3.2 database is a database that has been created using
Rem      the 7.3.2 release or upgraded to use the 7.3.2 release.
Rem
Rem    MODIFIED   (MM/DD/YY)
Rem    mramache    09/09/96 - run catrpc
Rem    lcprice     08/14/96 - 385242: add index create for hist_head$
Rem    sbalaram    04/09/96 - Upgrade script
Rem    sbalaram    04/09/96 - Created
Rem
 
Rem Add one more column "delivery_order" to system.repcat$_repprop.

ALTER TABLE system.repcat$_repprop ADD (delivery_order NUMBER DEFAULT NULL)
/

Rem Add index to hist_head$ table

create index i_hh_obj#_col# on hist_head$(obj#, col#)
/

Rem Need to run catrpc to add new obj# column to KGLR views.

@@catrpc


