rem 
rem $Header: oci13.sql,v 1.1 1995/03/05 23:30:17 vraghuna Exp $ 
rem 
Rem  Copyright (c) 1995 by Oracle Corporation 
Rem    NAME
Rem      oci13.sql
Rem    DESCRIPTION
Rem	 Script for A22400 OCI Techniques White Paper
Rem      Demo script for oci13.c
Rem    MODIFIED   (MM/DD/YY)
Rem     vraghuna   03/01/95 -  Creation
 
set echo on;
connect internal;
drop user ocitest cascade;
create user ocitest identified by ocitest;
grant connect,resource to ocitest;
connect ocitest/ocitest;

create table oci13tab (col1 number, col2 long);
 
insert into oci13tab values(1,  'A');
insert into oci13tab values(2,  'AB');
insert into oci13tab values(3,  'ABC');
insert into oci13tab values(4,  'ABCDEFGHIJKLM');
insert into oci13tab values(5,  'ABCD');
insert into oci13tab values(6,  'ABCDE');
insert into oci13tab values(7,  'ABCDEFGHIJ');
insert into oci13tab values(8,  '1');
insert into oci13tab values(9,  '12');
insert into oci13tab values(10, '123');
insert into oci13tab values(11, '123456789');
insert into oci13tab values(12, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ');
commit;
