rem 
rem $Header: dbmsobjg.sql,v 1.2 1994/03/28 09:47:27 adowning Exp $ 
rem 
Rem  Copyright (c) 1992 by Oracle Corporation 
Rem    NAME
Rem      dbmsobjg.sql - <one-line expansion of the name>
Rem    DESCRIPTION
Rem      <short description of component this file declares/defines>
Rem    RETURNS
Rem 
Rem    NOTES
Rem      <other useful comments, qualifications, etc.>
Rem    MODIFIED   (MM/DD/YY)
Rem     adowning   03/28/94 -  merge changes from branch 1.1.710.1
Rem     adowning   02/04/94 -  Creation
Rem
Rem NAME
Rem   dbmsobjg.sql - Object Generator (dbmsobjg)
Rem DESCRIPTION
Rem   These are private functions to be released in PL/SQL binary form.
