rem 
rem $Header: oci25.sql,v 1.1 1995/03/05 23:44:34 vraghuna Exp $ 
rem 
Rem  Copyright (c) 1995 by Oracle Corporation 
Rem    NAME
Rem      oci25.sql
Rem    DESCRIPTION
Rem	 Script for A22400 OCI Techniques White Paper
Rem      Demo script for oci25.c
Rem    MODIFIED   (MM/DD/YY)
Rem     vraghuna   03/01/95 -  Creation
REM
set echo on;
connect internal;

REM
REM Create a new user - call it ocitest
REM
drop user ocitest cascade;
create user ocitest identified by ocitest;
grant connect, resource to ocitest;

REM
REM Created needed tables 
REM
connect ocitest/ocitest;
drop table test1;
drop table test2;
drop table test3;
 
