:
#
# $Header: startup.sh@@/main/osit_unix_7.3.1/2 \
# Checked in on Sun Aug 20  4:34:11 US/Pacific 1995 by wyim \
# Copyright (c) 1995 by Oracle Corporation \
# $ Copyr (c) 1992 Oracle
#
svrmgrl 1> $1 2> $1 <<!
connect internal
startup
exit
!

