:
#
# $Header: chgpw.sh@@/main/osit_unix_7.3.1/2 \
# Checked in on Sun Aug 20  4:33:54 US/Pacific 1995 by wyim \
# Copyright (c) 1995 by Oracle Corporation \
# $ Copyr (c) 1992 Oracle
#
# Change system and sys password

echo ">> Changing SYSTEM and SYS passwords..."

svrmgrl <<!
connect system/manager;
grant connect to system identified by $SYSTEM_PW;

connect sys/change_on_install;
grant connect to sys identified by $SYS_PW;
!
