rem 
rem $Header: oci23.sql,v 1.1 1995/03/05 23:43:15 vraghuna Exp $ 
rem 
Rem  Copyright (c) 1995 by Oracle Corporation 
Rem    NAME
Rem      oci23.sql 
Rem    DESCRIPTION
Rem	 Script for A22400 OCI Techniques White Paper
Rem      Demo script for oci23.c
Rem    MODIFIED   (MM/DD/YY)
Rem     vraghuna   03/01/95 -  Creation
 
REM
REM Create a new user - call it ocitest
REM
drop user ocitest cascade;
create user ocitest identified by ocitest;
grant connect, resource to ocitest;

REM
REM Created needed tables 
REM
connect ocitest/ocitest;

create table oci23tab (one number not null, two long, three date, 
		four char(10));

