Rem 
Rem NAME
Rem    catnsnmp.sql
Rem  FUNCTION
Rem    Deletes the SNMPAgent role and DBSNMP user
Rem    (Reverses catsnmp.sql)
Rem  NOTES
Rem  MODIFIED
Rem
Rem  OWNER
Rem    ebosco
Rem



drop user DBSNMP cascade;

drop role SNMPAGENT;







