                                                                         
/* Copyright (c) 1988, 1996 by the Oracle Corporation.  All Rights Reserved. */
/*                                                                     */
/* ksms.s - Generated by genksms                                       */
/*                                                                     */
/* This is a derived file;  D O   N O T   E D I T                      */

	.set	sgabeg,0X80400000
	.globl	 ksmsgf_
	.set	ksmsgf_,sgabeg+0
	.globl	 ksmvsg_
	.set	ksmvsg_,sgabeg+4
	.globl	 ksmver_
	.set	ksmver_,sgabeg+8
	.globl	 ksmrdxf_
	.set	ksmrdxf_,sgabeg+12
	.globl	 ksmrdxl_
	.set	ksmrdxl_,sgabeg+16
	.globl	 ksmrpro_
	.set	ksmrpro_,sgabeg+20
	.globl	 ksmgsp_
	.set	ksmgsp_,sgabeg+24
	.globl	 ksmsgh_
	.set	ksmsgh_,sgabeg+28
	.globl	 ksmsul_
	.set	ksmsul_,sgabeg+240
	.globl	 ksmgsg_
	.set	ksmgsg_,sgabeg+1048
	.globl	 ksdflw_
	.set	ksdflw_,sgabeg+2288
	.globl	 kspmas_
	.set	kspmas_,sgabeg+2292
	.globl	 kslltl_
	.set	kslltl_,sgabeg+2296
	.globl	 kslltt_
	.set	kslltt_,sgabeg+2300
	.globl	 kslerb_
	.set	kslerb_,sgabeg+2540
	.globl	 kslnbe_
	.set	kslnbe_,sgabeg+2544
	.globl	 kslnla_
	.set	kslnla_,sgabeg+2548
	.globl	 kslnpo_
	.set	kslnpo_,sgabeg+2552
	.globl	 kslsesa_
	.set	kslsesa_,sgabeg+2556
	.globl	 kslesa_
	.set	kslesa_,sgabeg+2560
	.globl	 ksllasa_
	.set	ksllasa_,sgabeg+2564
	.globl	 kslposa_
	.set	kslposa_,sgabeg+2568
	.globl	 ksllata_
	.set	ksllata_,sgabeg+2572
	.globl	 ksllvl_
	.set	ksllvl_,sgabeg+2576
	.globl	 ksllae_
	.set	ksllae_,sgabeg+2600
	.globl	 ksllfe_
	.set	ksllfe_,sgabeg+2604
	.globl	 kslspi_
	.set	kslspi_,sgabeg+2608
	.globl	 kslmsl_
	.set	kslmsl_,sgabeg+2612
	.globl	 kslmex_
	.set	kslmex_,sgabeg+2616
	.globl	 kslpwt_
	.set	kslpwt_,sgabeg+2620
	.globl	 kslrpv_
	.set	kslrpv_,sgabeg+2624
	.globl	 kslwlst_
	.set	kslwlst_,sgabeg+2632
	.globl	 kslwlge_
	.set	kslwlge_,sgabeg+2780
	.globl	 kslwlfr_
	.set	kslwlfr_,sgabeg+2784
	.globl	 kslrgp_
	.set	kslrgp_,sgabeg+2788
	.globl	 kslrg2c_
	.set	kslrg2c_,sgabeg+2792
	.globl	 kslrgns_
	.set	kslrgns_,sgabeg+2796
	.globl	 kslrgnw_
	.set	kslrgnw_,sgabeg+2800
	.globl	 kslpo1_
	.set	kslpo1_,sgabeg+2804
	.globl	 kslpo2_
	.set	kslpo2_,sgabeg+2808
	.globl	 kslpo3_
	.set	kslpo3_,sgabeg+2812
	.globl	 kslpo4_
	.set	kslpo4_,sgabeg+2816
	.globl	 ksumca_
	.set	ksumca_,sgabeg+2820
	.globl	 ksufpe_
	.set	ksufpe_,sgabeg+2828
	.globl	 ksupte_
	.set	ksupte_,sgabeg+2832
	.globl	 ksuise_
	.set	ksuise_,sgabeg+2836
	.globl	 ksupal_
	.set	ksupal_,sgabeg+2840
	.globl	 ksusol_
	.set	ksusol_,sgabeg+2988
	.globl	 ksusal_
	.set	ksusal_,sgabeg+3136
	.globl	 ksupol_
	.set	ksupol_,sgabeg+3284
	.globl	 ksuiblp_
	.set	ksuiblp_,sgabeg+3432
	.globl	 ksuibln_
	.set	ksuibln_,sgabeg+3436
	.globl	 ksuilc_
	.set	ksuilc_,sgabeg+3440
	.globl	 ksusolc_
	.set	ksusolc_,sgabeg+3444
	.globl	 ksupira_
	.set	ksupira_,sgabeg+3448
	.globl	 ksupro_
	.set	ksupro_,sgabeg+3460
	.globl	 ksucal_
	.set	ksucal_,sgabeg+3464
	.globl	 ksuses_
	.set	ksuses_,sgabeg+3468
	.globl	 ksusca_
	.set	ksusca_,sgabeg+3472
	.globl	 ksusga_
	.set	ksusga_,sgabeg+3576
	.globl	 ksutec_
	.set	ksutec_,sgabeg+5072
	.globl	 ksusdi_
	.set	ksusdi_,sgabeg+5076
	.globl	 ksupcf_
	.set	ksupcf_,sgabeg+5080
	.globl	 ksulsga_
	.set	ksulsga_,sgabeg+5120
	.globl	 ksufix_
	.set	ksufix_,sgabeg+5136
	.globl	 ksuxxl_
	.set	ksuxxl_,sgabeg+5140
	.globl	 ksuxcl_
	.set	ksuxcl_,sgabeg+5144
	.globl	 ksuxoc_
	.set	ksuxoc_,sgabeg+5148
	.globl	 ksuxcc_
	.set	ksuxcc_,sgabeg+5152
	.globl	 ksuxuc_
	.set	ksuxuc_,sgabeg+5156
	.globl	 ksuxur_
	.set	ksuxur_,sgabeg+5160
	.globl	 ksuxxt_
	.set	ksuxxt_,sgabeg+5164
	.globl	 ksuxxr_
	.set	ksuxxr_,sgabeg+5168
	.globl	 ksuxrc_
	.set	ksuxrc_,sgabeg+5172
	.globl	 ksuxis_
	.set	ksuxis_,sgabeg+5176
	.globl	 ksuxpp_
	.set	ksuxpp_,sgabeg+5180
	.globl	 ksuxps_
	.set	ksuxps_,sgabeg+5184
	.globl	 ksuxpu_
	.set	ksuxpu_,sgabeg+5188
	.globl	 ksuxtc_
	.set	ksuxtc_,sgabeg+5192
	.globl	 ksuxti_
	.set	ksuxti_,sgabeg+5196
	.globl	 ksuxuz_
	.set	ksuxuz_,sgabeg+5200
	.globl	 ksuxmz_
	.set	ksuxmz_,sgabeg+5204
	.globl	 ksuxms_
	.set	ksuxms_,sgabeg+5208
	.globl	 ksuxmr_
	.set	ksuxmr_,sgabeg+5212
	.globl	 ksuxbt_
	.set	ksuxbt_,sgabeg+5216
	.globl	 ksuclp_
	.set	ksuclp_,sgabeg+5220
	.globl	 ksuso01_
	.set	ksuso01_,sgabeg+5312
	.globl	 ksuso02_
	.set	ksuso02_,sgabeg+5316
	.globl	 ksuso03_
	.set	ksuso03_,sgabeg+5320
	.globl	 ksuso04_
	.set	ksuso04_,sgabeg+5324
	.globl	 ksuso05_
	.set	ksuso05_,sgabeg+5328
	.globl	 ksuso06_
	.set	ksuso06_,sgabeg+5332
	.globl	 ksuso07_
	.set	ksuso07_,sgabeg+5336
	.globl	 ksuso08_
	.set	ksuso08_,sgabeg+5340
	.globl	 ksuso09_
	.set	ksuso09_,sgabeg+5344
	.globl	 ksuso10_
	.set	ksuso10_,sgabeg+5348
	.globl	 ksuso11_
	.set	ksuso11_,sgabeg+5352
	.globl	 ksuso12_
	.set	ksuso12_,sgabeg+5356
	.globl	 ksuso13_
	.set	ksuso13_,sgabeg+5360
	.globl	 ksuso14_
	.set	ksuso14_,sgabeg+5364
	.globl	 ksuso15_
	.set	ksuso15_,sgabeg+5368
	.globl	 ksuso16_
	.set	ksuso16_,sgabeg+5372
	.globl	 ksuso17_
	.set	ksuso17_,sgabeg+5376
	.globl	 ksuso18_
	.set	ksuso18_,sgabeg+5380
	.globl	 ksuso19_
	.set	ksuso19_,sgabeg+5384
	.globl	 ksupo01_
	.set	ksupo01_,sgabeg+5388
	.globl	 ksupo02_
	.set	ksupo02_,sgabeg+5392
	.globl	 ksupo03_
	.set	ksupo03_,sgabeg+5396
	.globl	 ksupo04_
	.set	ksupo04_,sgabeg+5400
	.globl	 ksupo05_
	.set	ksupo05_,sgabeg+5404
	.globl	 ksupo06_
	.set	ksupo06_,sgabeg+5408
	.globl	 ksupo07_
	.set	ksupo07_,sgabeg+5412
	.globl	 ksupo08_
	.set	ksupo08_,sgabeg+5416
	.globl	 ksupo09_
	.set	ksupo09_,sgabeg+5420
	.globl	 ksupo10_
	.set	ksupo10_,sgabeg+5424
	.globl	 ksusa01_
	.set	ksusa01_,sgabeg+5428
	.globl	 ksusa02_
	.set	ksusa02_,sgabeg+5432
	.globl	 ksusa03_
	.set	ksusa03_,sgabeg+5436
	.globl	 ksusa04_
	.set	ksusa04_,sgabeg+5440
	.globl	 ksusa05_
	.set	ksusa05_,sgabeg+5444
	.globl	 ksupa01_
	.set	ksupa01_,sgabeg+5448
	.globl	 ksupa02_
	.set	ksupa02_,sgabeg+5452
	.globl	 ksupa03_
	.set	ksupa03_,sgabeg+5456
	.globl	 ksups01_
	.set	ksups01_,sgabeg+5460
	.globl	 ksups02_
	.set	ksups02_,sgabeg+5464
	.globl	 ksups03_
	.set	ksups03_,sgabeg+5468
	.globl	 ksups04_
	.set	ksups04_,sgabeg+5472
	.globl	 ksups05_
	.set	ksups05_,sgabeg+5476
	.globl	 ksups06_
	.set	ksups06_,sgabeg+5480
	.globl	 ksbsga_
	.set	ksbsga_,sgabeg+5484
	.globl	 ksbmts_
	.set	ksbmts_,sgabeg+5500
	.globl	 ksbdpt_
	.set	ksbdpt_,sgabeg+5504
	.globl	 ksbcpu_
	.set	ksbcpu_,sgabeg+5932
	.globl	 ksbmes_
	.set	ksbmes_,sgabeg+5936
	.globl	 ksbgsb_
	.set	ksbgsb_,sgabeg+5944
	.globl	 ksbpse_
	.set	ksbpse_,sgabeg+5952
	.globl	 ksbpo01_
	.set	ksbpo01_,sgabeg+5956
	.globl	 ksbpo02_
	.set	ksbpo02_,sgabeg+5960
	.globl	 ksiper_
	.set	ksiper_,sgabeg+5964
	.globl	 ksimalp_
	.set	ksimalp_,sgabeg+5968
	.globl	 ksimaep_
	.set	ksimaep_,sgabeg+5976
	.globl	 ksimimap_
	.set	ksimimap_,sgabeg+5980
	.globl	 ksimnca_
	.set	ksimnca_,sgabeg+5984
	.globl	 ksimdmap_
	.set	ksimdmap_,sgabeg+5988
	.globl	 ksiminum_
	.set	ksiminum_,sgabeg+5992
	.globl	 ksimtnum_
	.set	ksimtnum_,sgabeg+5996
	.globl	 ksimsnum_
	.set	ksimsnum_,sgabeg+6000
	.globl	 ksimsmax_
	.set	ksimsmax_,sgabeg+6004
	.globl	 ksimnjl_
	.set	ksimnjl_,sgabeg+6008
	.globl	 ksimnrl_
	.set	ksimnrl_,sgabeg+6012
	.globl	 ksimnat_
	.set	ksimnat_,sgabeg+6016
	.globl	 ksimrec_
	.set	ksimrec_,sgabeg+6020
	.globl	 ksimcal_
	.set	ksimcal_,sgabeg+6024
	.globl	 ksiml1_
	.set	ksiml1_,sgabeg+6172
	.globl	 ksiml2_
	.set	ksiml2_,sgabeg+6176
	.globl	 ksiml3_
	.set	ksiml3_,sgabeg+6180
	.globl	 ksimgl_
	.set	ksimgl_,sgabeg+6184
	.globl	 ksimcl_
	.set	ksimcl_,sgabeg+6192
	.globl	 ksimjl_
	.set	ksimjl_,sgabeg+6200
	.globl	 ksimrl_
	.set	ksimrl_,sgabeg+6208
	.globl	 ksimsname_
	.set	ksimsname_,sgabeg+6216
	.globl	 ksdxec_
	.set	ksdxec_,sgabeg+6220
	.globl	 ksdxpo1_
	.set	ksdxpo1_,sgabeg+6224
	.globl	 ksmstv_
	.set	ksmstv_,sgabeg+6228
	.globl	 ksmstl_
	.set	ksmstl_,sgabeg+6324
	.globl	 ksmstt_
	.set	ksmstt_,sgabeg+6328
	.globl	 ksmsti_
	.set	ksmsti_,sgabeg+6332
	.globl	 ksmpcu_
	.set	ksmpcu_,sgabeg+6336
	.globl	 ksmpst_
	.set	ksmpst_,sgabeg+6340
	.globl	 ksplat_
	.set	ksplat_,sgabeg+6344
	.globl	 ksplcd_
	.set	ksplcd_,sgabeg+6492
	.globl	 kspsgs_
	.set	kspsgs_,sgabeg+6512
	.globl	 ksptbs_
	.set	ksptbs_,sgabeg+6516
	.globl	 ksppno_
	.set	ksppno_,sgabeg+6520
	.globl	 ksppzg_
	.set	ksppzg_,sgabeg+6524
	.globl	 kspla01_
	.set	kspla01_,sgabeg+6528
	.globl	 kspla02_
	.set	kspla02_,sgabeg+6532
	.globl	 kspla03_
	.set	kspla03_,sgabeg+6536
	.globl	 kspla04_
	.set	kspla04_,sgabeg+6540
	.globl	 ksetln_
	.set	ksetln_,sgabeg+6544
	.globl	 ksasga_
	.set	ksasga_,sgabeg+6548
	.globl	 ksamsl_
	.set	ksamsl_,sgabeg+6572
	.globl	 ksamae_
	.set	ksamae_,sgabeg+6720
	.globl	 ksarae_
	.set	ksarae_,sgabeg+6724
	.globl	 ksamse_
	.set	ksamse_,sgabeg+6728
	.globl	 ksaml01_
	.set	ksaml01_,sgabeg+6732
	.globl	 ksaml02_
	.set	ksaml02_,sgabeg+6736
	.globl	 ksaml03_
	.set	ksaml03_,sgabeg+6740
	.globl	 ksaml04_
	.set	ksaml04_,sgabeg+6744
	.globl	 ksaml05_
	.set	ksaml05_,sgabeg+6748
	.globl	 ksaml06_
	.set	ksaml06_,sgabeg+6752
	.globl	 ksaml07_
	.set	ksaml07_,sgabeg+6756
	.globl	 ksaml08_
	.set	ksaml08_,sgabeg+6760
	.globl	 ksaml09_
	.set	ksaml09_,sgabeg+6764
	.globl	 ksapo01_
	.set	ksapo01_,sgabeg+6768
	.globl	 ksapo02_
	.set	ksapo02_,sgabeg+6772
	.globl	 ksqgdn_
	.set	ksqgdn_,sgabeg+6776
	.globl	 ksqeae_
	.set	ksqeae_,sgabeg+6808
	.globl	 ksqlae_
	.set	ksqlae_,sgabeg+6812
	.globl	 ksqlhe_
	.set	ksqlhe_,sgabeg+6816
	.globl	 ksqlce_
	.set	ksqlce_,sgabeg+6820
	.globl	 ksqmi01_
	.set	ksqmi01_,sgabeg+6824
	.globl	 ksqmi02_
	.set	ksqmi02_,sgabeg+6828
	.globl	 ksqmi03_
	.set	ksqmi03_,sgabeg+6832
	.globl	 ksqmi04_
	.set	ksqmi04_,sgabeg+6836
	.globl	 ksqmi05_
	.set	ksqmi05_,sgabeg+6840
	.globl	 ksqmi06_
	.set	ksqmi06_,sgabeg+6844
	.globl	 ksqmi07_
	.set	ksqmi07_,sgabeg+6848
	.globl	 ksqmi08_
	.set	ksqmi08_,sgabeg+6852
	.globl	 ksqmi09_
	.set	ksqmi09_,sgabeg+6856
	.globl	 ksqhc01_
	.set	ksqhc01_,sgabeg+6860
	.globl	 ksqhc02_
	.set	ksqhc02_,sgabeg+6864
	.globl	 ksqhc03_
	.set	ksqhc03_,sgabeg+6868
	.globl	 ksqhc04_
	.set	ksqhc04_,sgabeg+6872
	.globl	 ksqhc05_
	.set	ksqhc05_,sgabeg+6876
	.globl	 ksqhc06_
	.set	ksqhc06_,sgabeg+6880
	.globl	 ksqhc07_
	.set	ksqhc07_,sgabeg+6884
	.globl	 ksqhc08_
	.set	ksqhc08_,sgabeg+6888
	.globl	 ksqhc09_
	.set	ksqhc09_,sgabeg+6892
	.globl	 ksqhc10_
	.set	ksqhc10_,sgabeg+6896
	.globl	 ksqhc11_
	.set	ksqhc11_,sgabeg+6900
	.globl	 ksqpo01_
	.set	ksqpo01_,sgabeg+6904
	.globl	 ksqpo02_
	.set	ksqpo02_,sgabeg+6908
	.globl	 ksqpo03_
	.set	ksqpo03_,sgabeg+6912
	.globl	 ksqpo04_
	.set	ksqpo04_,sgabeg+6916
	.globl	 ksqpo05_
	.set	ksqpo05_,sgabeg+6920
	.globl	 ksqpo06_
	.set	ksqpo06_,sgabeg+6924
	.globl	 ksqpo07_
	.set	ksqpo07_,sgabeg+6928
	.globl	 ksqsga_
	.set	ksqsga_,sgabeg+6932
	.globl	 ksqtyp_
	.set	ksqtyp_,sgabeg+7016
	.globl	 ksqxxt_
	.set	ksqxxt_,sgabeg+7020
	.globl	 ksqxxw_
	.set	ksqxxw_,sgabeg+7024
	.globl	 ksqxxd_
	.set	ksqxxd_,sgabeg+7028
	.globl	 ksqxxe_
	.set	ksqxxe_,sgabeg+7032
	.globl	 ksqxxc_
	.set	ksqxxc_,sgabeg+7036
	.globl	 ksqxxf_
	.set	ksqxxf_,sgabeg+7040
	.globl	 ksqeql_
	.set	ksqeql_,sgabeg+7044
	.globl	 ksqeqr_
	.set	ksqeqr_,sgabeg+7192
	.globl	 ksigc_
	.set	ksigc_,sgabeg+7340
	.globl	 ksiga_
	.set	ksiga_,sgabeg+7344
	.globl	 ksigt_
	.set	ksigt_,sgabeg+7348
	.globl	 ksicc_
	.set	ksicc_,sgabeg+7352
	.globl	 ksica_
	.set	ksica_,sgabeg+7356
	.globl	 ksict_
	.set	ksict_,sgabeg+7360
	.globl	 ksirc_
	.set	ksirc_,sgabeg+7364
	.globl	 ksira_
	.set	ksira_,sgabeg+7368
	.globl	 ksirt_
	.set	ksirt_,sgabeg+7372
	.globl	 ksilke_
	.set	ksilke_,sgabeg+7376
	.globl	 ksilre_
	.set	ksilre_,sgabeg+7380
	.globl	 ksilce_
	.set	ksilce_,sgabeg+7384
	.globl	 ksilae_
	.set	ksilae_,sgabeg+7388
	.globl	 ksilhe_
	.set	ksilhe_,sgabeg+7392
	.globl	 ksipo01_
	.set	ksipo01_,sgabeg+7396
	.globl	 ksipo02_
	.set	ksipo02_,sgabeg+7400
	.globl	 ksipo03_
	.set	ksipo03_,sgabeg+7404
	.globl	 ksmugd_
	.set	ksmugd_,sgabeg+7408
	.globl	 kstlt_
	.set	kstlt_,sgabeg+7412
	.globl	 kstrtb_
	.set	kstrtb_,sgabeg+7560
	.globl	 kstrib_
	.set	kstrib_,sgabeg+7564
	.globl	 kstibp_
	.set	kstibp_,sgabeg+7568
	.globl	 kstbsa_
	.set	kstbsa_,sgabeg+7572
	.globl	 kstntb_
	.set	kstntb_,sgabeg+7576
	.globl	 kstntr_
	.set	kstntr_,sgabeg+7580
	.globl	 kstbfp_
	.set	kstbfp_,sgabeg+7584
	.globl	 kstfl_
	.set	kstfl_,sgabeg+7588
	.globl	 ksten_
	.set	ksten_,sgabeg+7592
	.globl	 kstt2s_
	.set	kstt2s_,sgabeg+10344
	.globl	 kston_
	.set	kston_,sgabeg+10348
	.globl	 kstiov_
	.set	kstiov_,sgabeg+10352
	.globl	 kstfib_
	.set	kstfib_,sgabeg+10356
	.globl	 kstbhs_
	.set	kstbhs_,sgabeg+10360
	.globl	 kstacx_
	.set	kstacx_,sgabeg+10364
	.globl	 kstfsz_
	.set	kstfsz_,sgabeg+10368
	.globl	 kstwbs_
	.set	kstwbs_,sgabeg+10372
	.globl	 kstwrl_
	.set	kstwrl_,sgabeg+10376
	.globl	 kstton_
	.set	kstton_,sgabeg+10380
	.globl	 kstson_
	.set	kstson_,sgabeg+10384
	.globl	 kstfon_
	.set	kstfon_,sgabeg+10388
	.globl	 kstfrz_
	.set	kstfrz_,sgabeg+10392
	.globl	 kstfln_
	.set	kstfln_,sgabeg+10396
	.globl	 kstfko_
	.set	kstfko_,sgabeg+10656
	.globl	 kstdtp_
	.set	kstdtp_,sgabeg+10660
	.globl	 kstms_
	.set	kstms_,sgabeg+10752
	.globl	 kstmf_
	.set	kstmf_,sgabeg+10760
	.globl	 kstso_
	.set	kstso_,sgabeg+10768
	.globl	 kstefl_
	.set	kstefl_,sgabeg+10772
	.globl	 kstcnt_
	.set	kstcnt_,sgabeg+10776
	.globl	 kstufr_
	.set	kstufr_,sgabeg+10780
	.globl	 kstdbc_
	.set	kstdbc_,sgabeg+10784
	.globl	 kstlt01_
	.set	kstlt01_,sgabeg+10788
	.globl	 kstlt02_
	.set	kstlt02_,sgabeg+10792
	.globl	 ksulsg_
	.set	ksulsg_,sgabeg+10796
	.globl	 ksuxsd_
	.set	ksuxsd_,sgabeg+10804
	.globl	 kccsga_
	.set	kccsga_,sgabeg+10812
	.globl	 kcceqt_
	.set	kcceqt_,sgabeg+10932
	.globl	 kcccmpt_
	.set	kcccmpt_,sgabeg+10936
	.globl	 kccesr_
	.set	kccesr_,sgabeg+10952
	.globl	 kccesw_
	.set	kccesw_,sgabeg+10956
	.globl	 kccepw_
	.set	kccepw_,sgabeg+10960
	.globl	 kcbbbh_
	.set	kcbbbh_,sgabeg+10964
	.globl	 kcbbkl_
	.set	kcbbkl_,sgabeg+10968
	.globl	 kcbcks_
	.set	kcbcks_,sgabeg+10972
	.globl	 kcbldq_
	.set	kcbldq_,sgabeg+10976
	.globl	 kcbctb_
	.set	kcbctb_,sgabeg+10980
	.globl	 kcbdtl_
	.set	kcbdtl_,sgabeg+10984
	.globl	 kcbfbx_
	.set	kcbfbx_,sgabeg+10988
	.globl	 kcbhdl_
	.set	kcbhdl_,sgabeg+10992
	.globl	 kcbhln_
	.set	kcbhln_,sgabeg+10996
	.globl	 kcbhlp_
	.set	kcbhlp_,sgabeg+11000
	.globl	 kcbmbc_
	.set	kcbmbc_,sgabeg+11004
	.globl	 kcbmbf_
	.set	kcbmbf_,sgabeg+11008
	.globl	 kcbnbh_
	.set	kcbnbh_,sgabeg+11012
	.globl	 kcbnhb_
	.set	kcbnhb_,sgabeg+11016
	.globl	 kcbncb_
	.set	kcbncb_,sgabeg+11020
	.globl	 kcbnrb_
	.set	kcbnrb_,sgabeg+11024
	.globl	 kcbpro_
	.set	kcbpro_,sgabeg+11028
	.globl	 kcbqhb_
	.set	kcbqhb_,sgabeg+11032
	.globl	 kcbqrb_
	.set	kcbqrb_,sgabeg+11036
	.globl	 kcbrbq_
	.set	kcbrbq_,sgabeg+11044
	.globl	 kcbrtb_
	.set	kcbrtb_,sgabeg+11048
	.globl	 kcbnib_
	.set	kcbnib_,sgabeg+11052
	.globl	 kcbsdb_
	.set	kcbsdb_,sgabeg+11056
	.globl	 kcbsdl_
	.set	kcbsdl_,sgabeg+11060
	.globl	 kcbsdh_
	.set	kcbsdh_,sgabeg+11064
	.globl	 kcbsdi_
	.set	kcbsdi_,sgabeg+11068
	.globl	 kcbsdd_
	.set	kcbsdd_,sgabeg+11072
	.globl	 kcbsfs_
	.set	kcbsfs_,sgabeg+11076
	.globl	 kcbsoc_
	.set	kcbsoc_,sgabeg+11080
	.globl	 kcbsog_
	.set	kcbsog_,sgabeg+11084
	.globl	 kcbsca_
	.set	kcbsca_,sgabeg+11088
	.globl	 kcbfca_
	.set	kcbfca_,sgabeg+11092
	.globl	 kcbsop_
	.set	kcbsop_,sgabeg+11096
	.globl	 kcbswc_
	.set	kcbswc_,sgabeg+11100
	.globl	 kcbscc_
	.set	kcbscc_,sgabeg+11104
	.globl	 kcbsyw_
	.set	kcbsyw_,sgabeg+11108
	.globl	 kcbws_
	.set	kcbws_,sgabeg+11112
	.globl	 kcbwf_
	.set	kcbwf_,sgabeg+11116
	.globl	 kcbgbs_
	.set	kcbgbs_,sgabeg+11120
	.globl	 kcbusb_
	.set	kcbusb_,sgabeg+11124
	.globl	 kcbwst_
	.set	kcbwst_,sgabeg+11128
	.globl	 kcbwsc_
	.set	kcbwsc_,sgabeg+11132
	.globl	 kcbwsr_
	.set	kcbwsr_,sgabeg+11136
	.globl	 kcbwsls_
	.set	kcbwsls_,sgabeg+11140
	.globl	 kcbwslc_
	.set	kcbwslc_,sgabeg+11184
	.globl	 kcbcwb_
	.set	kcbcwb_,sgabeg+11208
	.globl	 kcbrbr1_
	.set	kcbrbr1_,sgabeg+11212
	.globl	 kcbrbr2_
	.set	kcbrbr2_,sgabeg+11216
	.globl	 kcbrbr3_
	.set	kcbrbr3_,sgabeg+11220
	.globl	 kcbcps_
	.set	kcbcps_,sgabeg+11224
	.globl	 kcbxrf_
	.set	kcbxrf_,sgabeg+11268
	.globl	 kcbdlx_
	.set	kcbdlx_,sgabeg+11272
	.globl	 kcbmcr_
	.set	kcbmcr_,sgabeg+11276
	.globl	 kcbhlx_
	.set	kcbhlx_,sgabeg+11280
	.globl	 kcbsol_
	.set	kcbsol_,sgabeg+11428
	.globl	 kcbmbl_
	.set	kcbmbl_,sgabeg+11576
	.globl	 kcbcpl_
	.set	kcbcpl_,sgabeg+11724
	.globl	 kcbbso_
	.set	kcbbso_,sgabeg+11872
	.globl	 kcbdwr_
	.set	kcbdwr_,sgabeg+11876
	.globl	 kcbbgt_
	.set	kcbbgt_,sgabeg+11968
	.globl	 kcbbgf_
	.set	kcbbgf_,sgabeg+11976
	.globl	 kcbbgc_
	.set	kcbbgc_,sgabeg+11984
	.globl	 kcbbgw_
	.set	kcbbgw_,sgabeg+11992
	.globl	 kcbbgi_
	.set	kcbbgi_,sgabeg+12000
	.globl	 kcbevf_
	.set	kcbevf_,sgabeg+12008
	.globl	 kcbevc_
	.set	kcbevc_,sgabeg+12012
	.globl	 kcbevb_
	.set	kcbevb_,sgabeg+12016
	.globl	 kcbevd_
	.set	kcbevd_,sgabeg+12020
	.globl	 kcbevl_
	.set	kcbevl_,sgabeg+12024
	.globl	 kcbevw_
	.set	kcbevw_,sgabeg+12028
	.globl	 kcbevr_
	.set	kcbevr_,sgabeg+12032
	.globl	 kcbevt_
	.set	kcbevt_,sgabeg+12036
	.globl	 kcbevcw_
	.set	kcbevcw_,sgabeg+12040
	.globl	 kcbevws_
	.set	kcbevws_,sgabeg+12044
	.globl	 kcbycu_
	.set	kcbycu_,sgabeg+12048
	.globl	 kcbycr_
	.set	kcbycr_,sgabeg+12052
	.globl	 kcbypr_
	.set	kcbypr_,sgabeg+12056
	.globl	 kcbypw_
	.set	kcbypw_,sgabeg+12060
	.globl	 kcbyir_
	.set	kcbyir_,sgabeg+12064
	.globl	 kcbylw_
	.set	kcbylw_,sgabeg+12068
	.globl	 kcbycc_
	.set	kcbycc_,sgabeg+12072
	.globl	 kcbytc_
	.set	kcbytc_,sgabeg+12076
	.globl	 kcbyxc_
	.set	kcbyxc_,sgabeg+12080
	.globl	 kcbyws_
	.set	kcbyws_,sgabeg+12084
	.globl	 kcbyts_
	.set	kcbyts_,sgabeg+12088
	.globl	 kcbyxd_
	.set	kcbyxd_,sgabeg+12092
	.globl	 kcbyfr_
	.set	kcbyfr_,sgabeg+12096
	.globl	 kcbyds_
	.set	kcbyds_,sgabeg+12100
	.globl	 kcbyfi_
	.set	kcbyfi_,sgabeg+12104
	.globl	 kcbywd_
	.set	kcbywd_,sgabeg+12108
	.globl	 kcbyhb_
	.set	kcbyhb_,sgabeg+12112
	.globl	 kcbybw_
	.set	kcbybw_,sgabeg+12116
	.globl	 kcbycf_
	.set	kcbycf_,sgabeg+12120
	.globl	 kcbytn_
	.set	kcbytn_,sgabeg+12124
	.globl	 kcbycs_
	.set	kcbycs_,sgabeg+12128
	.globl	 kcbybt_
	.set	kcbybt_,sgabeg+12132
	.globl	 kcbybl_
	.set	kcbybl_,sgabeg+12136
	.globl	 kcbyff_
	.set	kcbyff_,sgabeg+12140
	.globl	 kcbyls_
	.set	kcbyls_,sgabeg+12144
	.globl	 kcbysd_
	.set	kcbysd_,sgabeg+12148
	.globl	 kcbybs_
	.set	kcbybs_,sgabeg+12152
	.globl	 kcbybc_
	.set	kcbybc_,sgabeg+12156
	.globl	 kcbyli_
	.set	kcbyli_,sgabeg+12160
	.globl	 kcbyxw_
	.set	kcbyxw_,sgabeg+12164
	.globl	 kcbyxh_
	.set	kcbyxh_,sgabeg+12168
	.globl	 kcbyxq_
	.set	kcbyxq_,sgabeg+12172
	.globl	 kcbyxr_
	.set	kcbyxr_,sgabeg+12176
	.globl	 kcbyvb_
	.set	kcbyvb_,sgabeg+12180
	.globl	 kcbyva_
	.set	kcbyva_,sgabeg+12184
	.globl	 kcbyvt_
	.set	kcbyvt_,sgabeg+12188
	.globl	 kcbycb_
	.set	kcbycb_,sgabeg+12192
	.globl	 kcbycv_
	.set	kcbycv_,sgabeg+12196
	.globl	 kcbhq01_
	.set	kcbhq01_,sgabeg+12200
	.globl	 kcbhq02_
	.set	kcbhq02_,sgabeg+12204
	.globl	 kcbhq03_
	.set	kcbhq03_,sgabeg+12208
	.globl	 kcbhq04_
	.set	kcbhq04_,sgabeg+12212
	.globl	 kcbhq05_
	.set	kcbhq05_,sgabeg+12216
	.globl	 kcbhq06_
	.set	kcbhq06_,sgabeg+12220
	.globl	 kcbhq07_
	.set	kcbhq07_,sgabeg+12224
	.globl	 kcbhq08_
	.set	kcbhq08_,sgabeg+12228
	.globl	 kcbhq09_
	.set	kcbhq09_,sgabeg+12232
	.globl	 kcbhq10_
	.set	kcbhq10_,sgabeg+12236
	.globl	 kcbhq11_
	.set	kcbhq11_,sgabeg+12240
	.globl	 kcbhq12_
	.set	kcbhq12_,sgabeg+12244
	.globl	 kcbhq13_
	.set	kcbhq13_,sgabeg+12248
	.globl	 kcbhq14_
	.set	kcbhq14_,sgabeg+12252
	.globl	 kcbhq15_
	.set	kcbhq15_,sgabeg+12256
	.globl	 kcbhq16_
	.set	kcbhq16_,sgabeg+12260
	.globl	 kcbhq17_
	.set	kcbhq17_,sgabeg+12264
	.globl	 kcbhq18_
	.set	kcbhq18_,sgabeg+12268
	.globl	 kcbhq19_
	.set	kcbhq19_,sgabeg+12272
	.globl	 kcbhq20_
	.set	kcbhq20_,sgabeg+12276
	.globl	 kcbhq21_
	.set	kcbhq21_,sgabeg+12280
	.globl	 kcbhq22_
	.set	kcbhq22_,sgabeg+12284
	.globl	 kcbhq23_
	.set	kcbhq23_,sgabeg+12288
	.globl	 kcbhq24_
	.set	kcbhq24_,sgabeg+12292
	.globl	 kcbhq25_
	.set	kcbhq25_,sgabeg+12296
	.globl	 kcbhq26_
	.set	kcbhq26_,sgabeg+12300
	.globl	 kcbhq27_
	.set	kcbhq27_,sgabeg+12304
	.globl	 kcbhq28_
	.set	kcbhq28_,sgabeg+12308
	.globl	 kcbhq29_
	.set	kcbhq29_,sgabeg+12312
	.globl	 kcbhq30_
	.set	kcbhq30_,sgabeg+12316
	.globl	 kcbhq31_
	.set	kcbhq31_,sgabeg+12320
	.globl	 kcbhq32_
	.set	kcbhq32_,sgabeg+12324
	.globl	 kcbhq33_
	.set	kcbhq33_,sgabeg+12328
	.globl	 kcbhq34_
	.set	kcbhq34_,sgabeg+12332
	.globl	 kcbhq35_
	.set	kcbhq35_,sgabeg+12336
	.globl	 kcbhq36_
	.set	kcbhq36_,sgabeg+12340
	.globl	 kcbhq37_
	.set	kcbhq37_,sgabeg+12344
	.globl	 kcbhq38_
	.set	kcbhq38_,sgabeg+12348
	.globl	 kcbhq39_
	.set	kcbhq39_,sgabeg+12352
	.globl	 kcbhq40_
	.set	kcbhq40_,sgabeg+12356
	.globl	 kcbhq41_
	.set	kcbhq41_,sgabeg+12360
	.globl	 kcbhq42_
	.set	kcbhq42_,sgabeg+12364
	.globl	 kcbhq43_
	.set	kcbhq43_,sgabeg+12368
	.globl	 kcbmb01_
	.set	kcbmb01_,sgabeg+12372
	.globl	 kcbbh01_
	.set	kcbbh01_,sgabeg+12376
	.globl	 kcbbh02_
	.set	kcbbh02_,sgabeg+12380
	.globl	 kcbbh03_
	.set	kcbbh03_,sgabeg+12384
	.globl	 kcbbh04_
	.set	kcbbh04_,sgabeg+12388
	.globl	 kcbbh05_
	.set	kcbbh05_,sgabeg+12392
	.globl	 kcbbh06_
	.set	kcbbh06_,sgabeg+12396
	.globl	 kcbbh07_
	.set	kcbbh07_,sgabeg+12400
	.globl	 kcbbh08_
	.set	kcbbh08_,sgabeg+12404
	.globl	 kcbbh09_
	.set	kcbbh09_,sgabeg+12408
	.globl	 kcbbh10_
	.set	kcbbh10_,sgabeg+12412
	.globl	 kcbbs01_
	.set	kcbbs01_,sgabeg+12416
	.globl	 kcbbs02_
	.set	kcbbs02_,sgabeg+12420
	.globl	 kcbbs03_
	.set	kcbbs03_,sgabeg+12424
	.globl	 kcbbs04_
	.set	kcbbs04_,sgabeg+12428
	.globl	 kcbth01_
	.set	kcbth01_,sgabeg+12432
	.globl	 kcbzo01_
	.set	kcbzo01_,sgabeg+12436
	.globl	 kcbzo02_
	.set	kcbzo02_,sgabeg+12440
	.globl	 kcbzs01_
	.set	kcbzs01_,sgabeg+12444
	.globl	 kcbzs02_
	.set	kcbzs02_,sgabeg+12448
	.globl	 kcbzs03_
	.set	kcbzs03_,sgabeg+12452
	.globl	 kcbzs04_
	.set	kcbzs04_,sgabeg+12456
	.globl	 kcbzs05_
	.set	kcbzs05_,sgabeg+12460
	.globl	 kcbzh01_
	.set	kcbzh01_,sgabeg+12464
	.globl	 kcbzh02_
	.set	kcbzh02_,sgabeg+12468
	.globl	 kcbzh03_
	.set	kcbzh03_,sgabeg+12472
	.globl	 kcbzh04_
	.set	kcbzh04_,sgabeg+12476
	.globl	 kcbzh05_
	.set	kcbzh05_,sgabeg+12480
	.globl	 kcbzh06_
	.set	kcbzh06_,sgabeg+12484
	.globl	 kcbzh07_
	.set	kcbzh07_,sgabeg+12488
	.globl	 kcbzh08_
	.set	kcbzh08_,sgabeg+12492
	.globl	 kcbzh09_
	.set	kcbzh09_,sgabeg+12496
	.globl	 kcbzh10_
	.set	kcbzh10_,sgabeg+12500
	.globl	 kcbzh11_
	.set	kcbzh11_,sgabeg+12504
	.globl	 kcbzh12_
	.set	kcbzh12_,sgabeg+12508
	.globl	 kcbzw01_
	.set	kcbzw01_,sgabeg+12512
	.globl	 kcbzw02_
	.set	kcbzw02_,sgabeg+12516
	.globl	 kcbzw03_
	.set	kcbzw03_,sgabeg+12520
	.globl	 kcbzw04_
	.set	kcbzw04_,sgabeg+12524
	.globl	 kcbzw05_
	.set	kcbzw05_,sgabeg+12528
	.globl	 kcbzw06_
	.set	kcbzw06_,sgabeg+12532
	.globl	 kcbzw07_
	.set	kcbzw07_,sgabeg+12536
	.globl	 kcbzw08_
	.set	kcbzw08_,sgabeg+12540
	.globl	 kcbzw09_
	.set	kcbzw09_,sgabeg+12544
	.globl	 kcbzc01_
	.set	kcbzc01_,sgabeg+12548
	.globl	 kcbzm01_
	.set	kcbzm01_,sgabeg+12552
	.globl	 kcbzm02_
	.set	kcbzm02_,sgabeg+12556
	.globl	 kcbpo01_
	.set	kcbpo01_,sgabeg+12560
	.globl	 kcbpo02_
	.set	kcbpo02_,sgabeg+12564
	.globl	 kcbpo03_
	.set	kcbpo03_,sgabeg+12568
	.globl	 kcbpo04_
	.set	kcbpo04_,sgabeg+12572
	.globl	 kcbpo05_
	.set	kcbpo05_,sgabeg+12576
	.globl	 kcbpo06_
	.set	kcbpo06_,sgabeg+12580
	.globl	 kcbpo07_
	.set	kcbpo07_,sgabeg+12584
	.globl	 kcbpo08_
	.set	kcbpo08_,sgabeg+12588
	.globl	 kcbpo09_
	.set	kcbpo09_,sgabeg+12592
	.globl	 kcbwbd_
	.set	kcbwbd_,sgabeg+12596
	.globl	 kcbwss_
	.set	kcbwss_,sgabeg+12600
	.globl	 kcbwef_
	.set	kcbwef_,sgabeg+12604
	.globl	 kcbwlsx_
	.set	kcbwlsx_,sgabeg+12608
	.globl	 kcbw01_
	.set	kcbw01_,sgabeg+12756
	.globl	 kcbw02_
	.set	kcbw02_,sgabeg+12760
	.globl	 kcbw03_
	.set	kcbw03_,sgabeg+12764
	.globl	 kcbw04_
	.set	kcbw04_,sgabeg+12768
	.globl	 kcbw05_
	.set	kcbw05_,sgabeg+12772
	.globl	 kcbw06_
	.set	kcbw06_,sgabeg+12776
	.globl	 kcbw07_
	.set	kcbw07_,sgabeg+12780
	.globl	 kcbw08_
	.set	kcbw08_,sgabeg+12784
	.globl	 kcbw09_
	.set	kcbw09_,sgabeg+12788
	.globl	 kcbw10_
	.set	kcbw10_,sgabeg+12792
	.globl	 kcbw11_
	.set	kcbw11_,sgabeg+12796
	.globl	 kcbw12_
	.set	kcbw12_,sgabeg+12800
	.globl	 kcbw13_
	.set	kcbw13_,sgabeg+12804
	.globl	 kcbw14_
	.set	kcbw14_,sgabeg+12808
	.globl	 kcbw15_
	.set	kcbw15_,sgabeg+12812
	.globl	 kcbw16_
	.set	kcbw16_,sgabeg+12816
	.globl	 kcbw17_
	.set	kcbw17_,sgabeg+12820
	.globl	 kcbw18_
	.set	kcbw18_,sgabeg+12824
	.globl	 kcbw19_
	.set	kcbw19_,sgabeg+12828
	.globl	 kcbw20_
	.set	kcbw20_,sgabeg+12832
	.globl	 kcbw21_
	.set	kcbw21_,sgabeg+12836
	.globl	 kcbw22_
	.set	kcbw22_,sgabeg+12840
	.globl	 kcbw23_
	.set	kcbw23_,sgabeg+12844
	.globl	 kcbw100_
	.set	kcbw100_,sgabeg+12848
	.globl	 kcbw101_
	.set	kcbw101_,sgabeg+12852
	.globl	 kcbcict_
	.set	kcbcict_,sgabeg+12856
	.globl	 kcmrsn_
	.set	kcmrsn_,sgabeg+12872
	.globl	 kcmosn_
	.set	kcmosn_,sgabeg+12880
	.globl	 kcmrud_
	.set	kcmrud_,sgabeg+12888
	.globl	 kcmslt_
	.set	kcmslt_,sgabeg+12892
	.globl	 kcmmcd_
	.set	kcmmcd_,sgabeg+13040
	.globl	 kcmrsr_
	.set	kcmrsr_,sgabeg+13044
	.globl	 kcmurs_
	.set	kcmurs_,sgabeg+13048
	.globl	 kcmzcs_
	.set	kcmzcs_,sgabeg+13052
	.globl	 kcmzrs_
	.set	kcmzrs_,sgabeg+13056
	.globl	 kcmzas_
	.set	kcmzas_,sgabeg+13060
	.globl	 kcmznl_
	.set	kcmznl_,sgabeg+13064
	.globl	 kcmzuc_
	.set	kcmzuc_,sgabeg+13068
	.globl	 kcmzss_
	.set	kcmzss_,sgabeg+13072
	.globl	 kcmzwt_
	.set	kcmzwt_,sgabeg+13076
	.globl	 kcmzsb_
	.set	kcmzsb_,sgabeg+13080
	.globl	 kcmzcc_
	.set	kcmzcc_,sgabeg+13084
	.globl	 kcmevl_
	.set	kcmevl_,sgabeg+13088
	.globl	 kcmshr_
	.set	kcmshr_,sgabeg+13092
	.globl	 kcmagl_
	.set	kcmagl_,sgabeg+13096
	.globl	 kcmadl_
	.set	kcmadl_,sgabeg+13104
	.globl	 kcmacl_
	.set	kcmacl_,sgabeg+13112
	.globl	 kcmscnt_
	.set	kcmscnt_,sgabeg+13120
	.globl	 kcmfcnt_
	.set	kcmfcnt_,sgabeg+13124
	.globl	 kcmevb_
	.set	kcmevb_,sgabeg+13128
	.globl	 kcmxprc_
	.set	kcmxprc_,sgabeg+13132
	.globl	 kcmnprc_
	.set	kcmnprc_,sgabeg+13136
	.globl	 kcmncprc_
	.set	kcmncprc_,sgabeg+13140
	.globl	 kcmectm_
	.set	kcmectm_,sgabeg+13144
	.globl	 kcmncwat_
	.set	kcmncwat_,sgabeg+13148
	.globl	 kcmnncc_
	.set	kcmnncc_,sgabeg+13152
	.globl	 kcmcs01_
	.set	kcmcs01_,sgabeg+13156
	.globl	 kcmcs02_
	.set	kcmcs02_,sgabeg+13160
	.globl	 kcmcs03_
	.set	kcmcs03_,sgabeg+13164
	.globl	 kcmcs04_
	.set	kcmcs04_,sgabeg+13168
	.globl	 kcmcs05_
	.set	kcmcs05_,sgabeg+13172
	.globl	 kcmcs06_
	.set	kcmcs06_,sgabeg+13176
	.globl	 kcmcs07_
	.set	kcmcs07_,sgabeg+13180
	.globl	 kcmcs08_
	.set	kcmcs08_,sgabeg+13184
	.globl	 kcmcs09_
	.set	kcmcs09_,sgabeg+13188
	.globl	 kcmcs10_
	.set	kcmcs10_,sgabeg+13192
	.globl	 kcmcs11_
	.set	kcmcs11_,sgabeg+13196
	.globl	 kcmcs12_
	.set	kcmcs12_,sgabeg+13200
	.globl	 kcmcs13_
	.set	kcmcs13_,sgabeg+13204
	.globl	 kcmcs14_
	.set	kcmcs14_,sgabeg+13208
	.globl	 kcmcs15_
	.set	kcmcs15_,sgabeg+13212
	.globl	 kcmcs16_
	.set	kcmcs16_,sgabeg+13216
	.globl	 kcmcs17_
	.set	kcmcs17_,sgabeg+13220
	.globl	 kcmcs18_
	.set	kcmcs18_,sgabeg+13224
	.globl	 kcmcs19_
	.set	kcmcs19_,sgabeg+13228
	.globl	 kcmcs20_
	.set	kcmcs20_,sgabeg+13232
	.globl	 kcmcs21_
	.set	kcmcs21_,sgabeg+13236
	.globl	 kcmcs22_
	.set	kcmcs22_,sgabeg+13240
	.globl	 kcmcs23_
	.set	kcmcs23_,sgabeg+13244
	.globl	 kcmcs24_
	.set	kcmcs24_,sgabeg+13248
	.globl	 kcmcs25_
	.set	kcmcs25_,sgabeg+13252
	.globl	 kcmcs26_
	.set	kcmcs26_,sgabeg+13256
	.globl	 kcmcs27_
	.set	kcmcs27_,sgabeg+13260
	.globl	 kcmcs28_
	.set	kcmcs28_,sgabeg+13264
	.globl	 kcmcs29_
	.set	kcmcs29_,sgabeg+13268
	.globl	 kcmcs30_
	.set	kcmcs30_,sgabeg+13272
	.globl	 kcmcs31_
	.set	kcmcs31_,sgabeg+13276
	.globl	 kcmcs32_
	.set	kcmcs32_,sgabeg+13280
	.globl	 kcmcs33_
	.set	kcmcs33_,sgabeg+13284
	.globl	 kcmra01_
	.set	kcmra01_,sgabeg+13288
	.globl	 kcmra02_
	.set	kcmra02_,sgabeg+13292
	.globl	 kcmra03_
	.set	kcmra03_,sgabeg+13296
	.globl	 kcmra04_
	.set	kcmra04_,sgabeg+13300
	.globl	 kcmra05_
	.set	kcmra05_,sgabeg+13304
	.globl	 kcmra06_
	.set	kcmra06_,sgabeg+13308
	.globl	 kcmra07_
	.set	kcmra07_,sgabeg+13312
	.globl	 kcmra08_
	.set	kcmra08_,sgabeg+13316
	.globl	 kckcpt_
	.set	kckcpt_,sgabeg+13320
	.globl	 kckrdt_
	.set	kckrdt_,sgabeg+13336
	.globl	 kckudt_
	.set	kckudt_,sgabeg+13352
	.globl	 kckbtt_
	.set	kckbtt_,sgabeg+13368
	.globl	 kckfrt_
	.set	kckfrt_,sgabeg+13384
	.globl	 kcksga_
	.set	kcksga_,sgabeg+13400
	.globl	 kcracb_
	.set	kcracb_,sgabeg+13424
	.globl	 kcrrae_
	.set	kcrrae_,sgabeg+13428
	.globl	 kcrrsk_
	.set	kcrrsk_,sgabeg+13432
	.globl	 kcrrss_
	.set	kcrrss_,sgabeg+13436
	.globl	 kcrrta_
	.set	kcrrta_,sgabeg+13440
	.globl	 kcrroe_
	.set	kcrroe_,sgabeg+13444
	.globl	 kcrrms_
	.set	kcrrms_,sgabeg+13448
	.globl	 kcrres_
	.set	kcrres_,sgabeg+13452
	.globl	 kcrrac_
	.set	kcrrac_,sgabeg+13456
	.globl	 kcrrlt_
	.set	kcrrlt_,sgabeg+13712
	.globl	 kcrrle_
	.set	kcrrle_,sgabeg+13860
	.globl	 kcrrbf_
	.set	kcrrbf_,sgabeg+13864
	.globl	 kcrrbz_
	.set	kcrrbz_,sgabeg+13868
	.globl	 kcrrdp_
	.set	kcrrdp_,sgabeg+13872
	.globl	 kcrrwa_
	.set	kcrrwa_,sgabeg+13964
	.globl	 kcrrma_
	.set	kcrrma_,sgabeg+13972
	.globl	 kcrrsh_
	.set	kcrrsh_,sgabeg+13980
	.globl	 kcrra01_
	.set	kcrra01_,sgabeg+13988
	.globl	 kcrra02_
	.set	kcrra02_,sgabeg+13992
	.globl	 kcrra03_
	.set	kcrra03_,sgabeg+13996
	.globl	 kcrfal_
	.set	kcrfal_,sgabeg+14000
	.globl	 kcrprc_
	.set	kcrprc_,sgabeg+14148
	.globl	 kcrfer_
	.set	kcrfer_,sgabeg+14240
	.globl	 kcrfew_
	.set	kcrfew_,sgabeg+14244
	.globl	 kcrfep_
	.set	kcrfep_,sgabeg+14248
	.globl	 kcral01_
	.set	kcral01_,sgabeg+14252
	.globl	 kcral02_
	.set	kcral02_,sgabeg+14256
	.globl	 kcral03_
	.set	kcral03_,sgabeg+14260
	.globl	 kcral04_
	.set	kcral04_,sgabeg+14264
	.globl	 kcral05_
	.set	kcral05_,sgabeg+14268
	.globl	 kcral06_
	.set	kcral06_,sgabeg+14272
	.globl	 kcral07_
	.set	kcral07_,sgabeg+14276
	.globl	 kcral08_
	.set	kcral08_,sgabeg+14280
	.globl	 kcral09_
	.set	kcral09_,sgabeg+14284
	.globl	 kcral10_
	.set	kcral10_,sgabeg+14288
	.globl	 kcral11_
	.set	kcral11_,sgabeg+14292
	.globl	 kcral12_
	.set	kcral12_,sgabeg+14296
	.globl	 kcral13_
	.set	kcral13_,sgabeg+14300
	.globl	 kcral14_
	.set	kcral14_,sgabeg+14304
	.globl	 kcral15_
	.set	kcral15_,sgabeg+14308
	.globl	 kcral16_
	.set	kcral16_,sgabeg+14312
	.globl	 kcral17_
	.set	kcral17_,sgabeg+14316
	.globl	 kcrcl01_
	.set	kcrcl01_,sgabeg+14320
	.globl	 kcrcl02_
	.set	kcrcl02_,sgabeg+14324
	.globl	 kcrcl03_
	.set	kcrcl03_,sgabeg+14328
	.globl	 kcrfcp_
	.set	kcrfcp_,sgabeg+14332
	.globl	 kcrfsg_
	.set	kcrfsg_,sgabeg+14480
	.globl	 kcrfea_
	.set	kcrfea_,sgabeg+14836
	.globl	 kcrfsch_
	.set	kcrfsch_,sgabeg+14840
	.globl	 kcrfsar_
	.set	kcrfsar_,sgabeg+14844
	.globl	 kcrfscl_
	.set	kcrfscl_,sgabeg+14848
	.globl	 kcrfsus_
	.set	kcrfsus_,sgabeg+14852
	.globl	 kcrfsot_
	.set	kcrfsot_,sgabeg+14856
	.globl	 kcrfes_
	.set	kcrfes_,sgabeg+14860
	.globl	 kcrywi_
	.set	kcrywi_,sgabeg+14864
	.globl	 kcrywl_
	.set	kcrywl_,sgabeg+14872
	.globl	 kcrywg_
	.set	kcrywg_,sgabeg+14880
	.globl	 kcrqte_
	.set	kcrqte_,sgabeg+14888
	.globl	 kcrqts_
	.set	kcrqts_,sgabeg+14892
	.globl	 kcrqel_
	.set	kcrqel_,sgabeg+14896
	.globl	 kcrqaf_
	.set	kcrqaf_,sgabeg+14900
	.globl	 kcrqsc_
	.set	kcrqsc_,sgabeg+14904
	.globl	 kcrqwa_
	.set	kcrqwa_,sgabeg+14908
	.globl	 kcrqct_
	.set	kcrqct_,sgabeg+14912
	.globl	 kcrqwc_
	.set	kcrqwc_,sgabeg+14916
	.globl	 kcrqwb_
	.set	kcrqwb_,sgabeg+14920
	.globl	 kcrqwt_
	.set	kcrqwt_,sgabeg+14924
	.globl	 kcrqgs_
	.set	kcrqgs_,sgabeg+14928
	.globl	 kcrqgt_
	.set	kcrqgt_,sgabeg+14932
	.globl	 kcrqmi_
	.set	kcrqmi_,sgabeg+14936
	.globl	 kcrqor_
	.set	kcrqor_,sgabeg+14940
	.globl	 kcrfcpt_
	.set	kcrfcpt_,sgabeg+14944
	.globl	 kcrfroc_
	.set	kcrfroc_,sgabeg+14960
	.globl	 kcfcfk_
	.set	kcfcfk_,sgabeg+14976
	.globl	 kcfdfk_
	.set	kcfdfk_,sgabeg+14980
	.globl	 kcflfk_
	.set	kcflfk_,sgabeg+14984
	.globl	 kcfmsw_
	.set	kcfmsw_,sgabeg+14988
	.globl	 kcffbs_
	.set	kcffbs_,sgabeg+14992
	.globl	 kcfios_
	.set	kcfios_,sgabeg+14996
	.globl	 kcffsq_
	.set	kcffsq_,sgabeg+15000
	.globl	 kcffsz_
	.set	kcffsz_,sgabeg+15004
	.globl	 kcffon_
	.set	kcffon_,sgabeg+15008
	.globl	 kcffrd_
	.set	kcffrd_,sgabeg+15012
	.globl	 kcffcg_
	.set	kcffcg_,sgabeg+15016
	.globl	 kcffro_
	.set	kcffro_,sgabeg+15020
	.globl	 kcffcn_
	.set	kcffcn_,sgabeg+15024
	.globl	 kcffls_
	.set	kcffls_,sgabeg+15028
	.globl	 kcfflc_
	.set	kcfflc_,sgabeg+15032
	.globl	 kcfdbm_
	.set	kcfdbm_,sgabeg+15036
	.globl	 kcfdbo_
	.set	kcfdbo_,sgabeg+15040
	.globl	 kcfgos_
	.set	kcfgos_,sgabeg+15044
	.globl	 kcfnxo_
	.set	kcfnxo_,sgabeg+15048
	.globl	 kcfmts_
	.set	kcfmts_,sgabeg+15052
	.globl	 kcfhms_
	.set	kcfhms_,sgabeg+15096
	.globl	 kcfhos_
	.set	kcfhos_,sgabeg+15140
	.globl	 kcfofq_
	.set	kcfofq_,sgabeg+15184
	.globl	 kcfalm_
	.set	kcfalm_,sgabeg+15188
	.globl	 kcfafc_
	.set	kcfafc_,sgabeg+15196
	.globl	 kcfsml_
	.set	kcfsml_,sgabeg+15204
	.globl	 kcfco1_
	.set	kcfco1_,sgabeg+15212
	.globl	 kcfco2_
	.set	kcfco2_,sgabeg+15220
	.globl	 kcfco3_
	.set	kcfco3_,sgabeg+15228
	.globl	 kcfco4_
	.set	kcfco4_,sgabeg+15236
	.globl	 kcfaof_
	.set	kcfaof_,sgabeg+15244
	.globl	 kcfaid_
	.set	kcfaid_,sgabeg+15252
	.globl	 kcfamt_
	.set	kcfamt_,sgabeg+15260
	.globl	 kcfevf_
	.set	kcfevf_,sgabeg+15268
	.globl	 kcferc_
	.set	kcferc_,sgabeg+15272
	.globl	 kcferd_
	.set	kcferd_,sgabeg+15276
	.globl	 kcfesr_
	.set	kcfesr_,sgabeg+15280
	.globl	 kcfesw_
	.set	kcfesw_,sgabeg+15284
	.globl	 kcfepw_
	.set	kcfepw_,sgabeg+15288
	.globl	 kcfrl01_
	.set	kcfrl01_,sgabeg+15292
	.globl	 kcfrl02_
	.set	kcfrl02_,sgabeg+15296
	.globl	 kcfrl03_
	.set	kcfrl03_,sgabeg+15300
	.globl	 kcfpo01_
	.set	kcfpo01_,sgabeg+15304
	.globl	 kclblp_
	.set	kclblp_,sgabeg+15308
	.globl	 kclmcl_
	.set	kclmcl_,sgabeg+15312
	.globl	 kclflt_
	.set	kclflt_,sgabeg+15316
	.globl	 kclnlt_
	.set	kclnlt_,sgabeg+15464
	.globl	 kclsga_
	.set	kclsga_,sgabeg+15612
	.globl	 kcllst_
	.set	kcllst_,sgabeg+15616
	.globl	 kcllcf_
	.set	kcllcf_,sgabeg+15620
	.globl	 kclbcc_
	.set	kclbcc_,sgabeg+15624
	.globl	 kclbrc_
	.set	kclbrc_,sgabeg+15628
	.globl	 kclber_
	.set	kclber_,sgabeg+15632
	.globl	 kclbre_
	.set	kclbre_,sgabeg+15636
	.globl	 kclbrl_
	.set	kclbrl_,sgabeg+15640
	.globl	 kclnhl_
	.set	kclnhl_,sgabeg+15644
	.globl	 kclsts_
	.set	kclsts_,sgabeg+15648
	.globl	 kclpm_
	.set	kclpm_,sgabeg+15652
	.globl	 kclncl_
	.set	kclncl_,sgabeg+15656
	.globl	 kclbaq_
	.set	kclbaq_,sgabeg+15660
	.globl	 kclso_
	.set	kclso_,sgabeg+15664
	.globl	 kclcmpt_
	.set	kclcmpt_,sgabeg+15668
	.globl	 kclpr0_
	.set	kclpr0_,sgabeg+15684
	.globl	 kclpr1_
	.set	kclpr1_,sgabeg+15776
	.globl	 kclpr2_
	.set	kclpr2_,sgabeg+15868
	.globl	 kclpr3_
	.set	kclpr3_,sgabeg+15960
	.globl	 kclpr4_
	.set	kclpr4_,sgabeg+16052
	.globl	 kclpr5_
	.set	kclpr5_,sgabeg+16144
	.globl	 kclpr6_
	.set	kclpr6_,sgabeg+16236
	.globl	 kclpr7_
	.set	kclpr7_,sgabeg+16328
	.globl	 kclpr8_
	.set	kclpr8_,sgabeg+16420
	.globl	 kclpr9_
	.set	kclpr9_,sgabeg+16512
	.globl	 kclscv_
	.set	kclscv_,sgabeg+16604
	.globl	 kclscu_
	.set	kclscu_,sgabeg+16612
	.globl	 kclsil_
	.set	kclsil_,sgabeg+16620
	.globl	 kclsfl_
	.set	kclsfl_,sgabeg+16628
	.globl	 kclssl_
	.set	kclssl_,sgabeg+16636
	.globl	 kclsrl_
	.set	kclsrl_,sgabeg+16644
	.globl	 kclbia_
	.set	kclbia_,sgabeg+16652
	.globl	 kclscl_
	.set	kclscl_,sgabeg+16660
	.globl	 kcllil_
	.set	kcllil_,sgabeg+16668
	.globl	 kcllt_
	.set	kcllt_,sgabeg+16816
	.globl	 kclnwt_
	.set	kclnwt_,sgabeg+16964
	.globl	 kclevb_
	.set	kclevb_,sgabeg+16968
	.globl	 kclevl_
	.set	kclevl_,sgabeg+16972
	.globl	 kclevi_
	.set	kclevi_,sgabeg+16976
	.globl	 kclevg_
	.set	kclevg_,sgabeg+16980
	.globl	 kclfl01_
	.set	kclfl01_,sgabeg+16984
	.globl	 kclfl02_
	.set	kclfl02_,sgabeg+16988
	.globl	 kclfl03_
	.set	kclfl03_,sgabeg+16992
	.globl	 kclfl04_
	.set	kclfl04_,sgabeg+16996
	.globl	 kclil01_
	.set	kclil01_,sgabeg+17000
	.globl	 kclil02_
	.set	kclil02_,sgabeg+17004
	.globl	 kclil03_
	.set	kclil03_,sgabeg+17008
	.globl	 kclil04_
	.set	kclil04_,sgabeg+17012
	.globl	 kclil05_
	.set	kclil05_,sgabeg+17016
	.globl	 kclil06_
	.set	kclil06_,sgabeg+17020
	.globl	 kclil07_
	.set	kclil07_,sgabeg+17024
	.globl	 kclil08_
	.set	kclil08_,sgabeg+17028
	.globl	 kclil09_
	.set	kclil09_,sgabeg+17032
	.globl	 kclil10_
	.set	kclil10_,sgabeg+17036
	.globl	 kclil11_
	.set	kclil11_,sgabeg+17040
	.globl	 kclil12_
	.set	kclil12_,sgabeg+17044
	.globl	 kclil13_
	.set	kclil13_,sgabeg+17048
	.globl	 kclil14_
	.set	kclil14_,sgabeg+17052
	.globl	 kclil15_
	.set	kclil15_,sgabeg+17056
	.globl	 kclil16_
	.set	kclil16_,sgabeg+17060
	.globl	 kclil17_
	.set	kclil17_,sgabeg+17064
	.globl	 kclil18_
	.set	kclil18_,sgabeg+17068
	.globl	 kclil19_
	.set	kclil19_,sgabeg+17072
	.globl	 kclil20_
	.set	kclil20_,sgabeg+17076
	.globl	 kclil21_
	.set	kclil21_,sgabeg+17080
	.globl	 kclil22_
	.set	kclil22_,sgabeg+17084
	.globl	 kclhc01_
	.set	kclhc01_,sgabeg+17088
	.globl	 kclhc02_
	.set	kclhc02_,sgabeg+17092
	.globl	 kclhc03_
	.set	kclhc03_,sgabeg+17096
	.globl	 kclhc04_
	.set	kclhc04_,sgabeg+17100
	.globl	 kclhc05_
	.set	kclhc05_,sgabeg+17104
	.globl	 kclhc06_
	.set	kclhc06_,sgabeg+17108
	.globl	 kclhc07_
	.set	kclhc07_,sgabeg+17112
	.globl	 kclhc08_
	.set	kclhc08_,sgabeg+17116
	.globl	 kclsl01_
	.set	kclsl01_,sgabeg+17120
	.globl	 kclsl02_
	.set	kclsl02_,sgabeg+17124
	.globl	 kclsl03_
	.set	kclsl03_,sgabeg+17128
	.globl	 kclsl04_
	.set	kclsl04_,sgabeg+17132
	.globl	 kclsl05_
	.set	kclsl05_,sgabeg+17136
	.globl	 kclsl06_
	.set	kclsl06_,sgabeg+17140
	.globl	 kclsl07_
	.set	kclsl07_,sgabeg+17144
	.globl	 kclsl08_
	.set	kclsl08_,sgabeg+17148
	.globl	 kclsd01_
	.set	kclsd01_,sgabeg+17152
	.globl	 kclnt02_
	.set	kclnt02_,sgabeg+17156
	.globl	 kclnt03_
	.set	kclnt03_,sgabeg+17160
	.globl	 kclle01_
	.set	kclle01_,sgabeg+17164
	.globl	 kclle02_
	.set	kclle02_,sgabeg+17168
	.globl	 kclle03_
	.set	kclle03_,sgabeg+17172
	.globl	 kclle04_
	.set	kclle04_,sgabeg+17176
	.globl	 kclle05_
	.set	kclle05_,sgabeg+17180
	.globl	 kclle06_
	.set	kclle06_,sgabeg+17184
	.globl	 kclle07_
	.set	kclle07_,sgabeg+17188
	.globl	 kclle08_
	.set	kclle08_,sgabeg+17192
	.globl	 kclle09_
	.set	kclle09_,sgabeg+17196
	.globl	 kclle10_
	.set	kclle10_,sgabeg+17200
	.globl	 kclle11_
	.set	kclle11_,sgabeg+17204
	.globl	 kclle12_
	.set	kclle12_,sgabeg+17208
	.globl	 kclps1_
	.set	kclps1_,sgabeg+17212
	.globl	 kclps2_
	.set	kclps2_,sgabeg+17216
	.globl	 kclps3_
	.set	kclps3_,sgabeg+17220
	.globl	 kclps4_
	.set	kclps4_,sgabeg+17224
	.globl	 kclps5_
	.set	kclps5_,sgabeg+17228
	.globl	 kclps6_
	.set	kclps6_,sgabeg+17232
	.globl	 kclps7_
	.set	kclps7_,sgabeg+17236
	.globl	 kclps8_
	.set	kclps8_,sgabeg+17240
	.globl	 kclps9_
	.set	kclps9_,sgabeg+17244
	.globl	 kclps10_
	.set	kclps10_,sgabeg+17248
	.globl	 kclps11_
	.set	kclps11_,sgabeg+17252
	.globl	 kclps12_
	.set	kclps12_,sgabeg+17256
	.globl	 kclps13_
	.set	kclps13_,sgabeg+17260
	.globl	 kcblei_
	.set	kcblei_,sgabeg+17264
	.globl	 kcblqw_
	.set	kcblqw_,sgabeg+17268
	.globl	 kcblso_
	.set	kcblso_,sgabeg+17272
	.globl	 kcblsog_
	.set	kcblsog_,sgabeg+17276
	.globl	 kcblsol_
	.set	kcblsol_,sgabeg+17280
	.globl	 kcblso01_
	.set	kcblso01_,sgabeg+17428
	.globl	 kcblso02_
	.set	kcblso02_,sgabeg+17432
	.globl	 kctsat_
	.set	kctsat_,sgabeg+17436
	.globl	 kcteln_
	.set	kcteln_,sgabeg+17440
	.globl	 kctmtq_
	.set	kctmtq_,sgabeg+17444
	.globl	 kctenq_
	.set	kctenq_,sgabeg+17448
	.globl	 kctloq_
	.set	kctloq_,sgabeg+17500
	.globl	 kctdoq_
	.set	kctdoq_,sgabeg+17504
	.globl	 kctkls_
	.set	kctkls_,sgabeg+17508
	.globl	 kctklc_
	.set	kctklc_,sgabeg+17552
	.globl	 kctath_
	.set	kctath_,sgabeg+17576
	.globl	 kctadq_
	.set	kctadq_,sgabeg+17584
	.globl	 kctthr_
	.set	kctthr_,sgabeg+17592
	.globl	 kcvfvr_
	.set	kcvfvr_,sgabeg+17596
	.globl	 kcvrts_
	.set	kcvrts_,sgabeg+17600
	.globl	 kcvblg_
	.set	kcvblg_,sgabeg+17604
	.globl	 kcvbbl_
	.set	kcvbbl_,sgabeg+17608
	.globl	 kcvrls_
	.set	kcvrls_,sgabeg+17612
	.globl	 kcvrlc_
	.set	kcvrlc_,sgabeg+17620
	.globl	 kcvdbn_
	.set	kcvdbn_,sgabeg+17624
	.globl	 kcvckp_
	.set	kcvckp_,sgabeg+17628
	.globl	 kcvcpa_
	.set	kcvcpa_,sgabeg+17664
	.globl	 kcvlcm_
	.set	kcvlcm_,sgabeg+17668
	.globl	 kcvcpr_
	.set	kcvcpr_,sgabeg+17672
	.globl	 kcvgcw_
	.set	kcvgcw_,sgabeg+17676
	.globl	 kcvcpd_
	.set	kcvcpd_,sgabeg+17680
	.globl	 kcvcpf_
	.set	kcvcpf_,sgabeg+17684
	.globl	 kcvcpp_
	.set	kcvcpp_,sgabeg+17688
	.globl	 kcvqfa_
	.set	kcvqfa_,sgabeg+17692
	.globl	 kcvccr_
	.set	kcvccr_,sgabeg+17696
	.globl	 kcvccc_
	.set	kcvccc_,sgabeg+17704
	.globl	 kcvals_
	.set	kcvals_,sgabeg+17712
	.globl	 kcvcdp_
	.set	kcvcdp_,sgabeg+17720
	.globl	 kcvarv_
	.set	kcvarv_,sgabeg+17812
	.globl	 kcvavi_
	.set	kcvavi_,sgabeg+17820
	.globl	 kcvybs_
	.set	kcvybs_,sgabeg+17828
	.globl	 kcvybc_
	.set	kcvybc_,sgabeg+17832
	.globl	 kcvcmpt_
	.set	kcvcmpt_,sgabeg+17836
	.globl	 kcvredo_
	.set	kcvredo_,sgabeg+17852
	.globl	 kcvpo01_
	.set	kcvpo01_,sgabeg+17868
	.globl	 kcrpsv_
	.set	kcrpsv_,sgabeg+17872
	.globl	 kcrpctl_
	.set	kcrpctl_,sgabeg+17876
	.globl	 kcrpdat_
	.set	kcrpdat_,sgabeg+17880
	.globl	 kcrpcrp_
	.set	kcrpcrp_,sgabeg+17884
	.globl	 kcrpsdq_
	.set	kcrpsdq_,sgabeg+17888
	.globl	 ktasga_
	.set	ktasga_,sgabeg+17892
	.globl	 ktasol_
	.set	ktasol_,sgabeg+17972
	.globl	 ktadmt_
	.set	ktadmt_,sgabeg+18120
	.globl	 ktatlt_
	.set	ktatlt_,sgabeg+18124
	.globl	 ktaimd_
	.set	ktaimd_,sgabeg+18128
	.globl	 ktaso01_
	.set	ktaso01_,sgabeg+18136
	.globl	 ktaso02_
	.set	ktaso02_,sgabeg+18140
	.globl	 ktaso03_
	.set	ktaso03_,sgabeg+18144
	.globl	 ktaso04_
	.set	ktaso04_,sgabeg+18148
	.globl	 ktbsza_
	.set	ktbsza_,sgabeg+18152
	.globl	 ktlsga_
	.set	ktlsga_,sgabeg+18156
	.globl	 ktldlc_
	.set	ktldlc_,sgabeg+18168
	.globl	 ktlbkl_
	.set	ktlbkl_,sgabeg+18172
	.globl	 ktlbkt_
	.set	ktlbkt_,sgabeg+18320
	.globl	 ktlbk01_
	.set	ktlbk01_,sgabeg+18324
	.globl	 ktlbk02_
	.set	ktlbk02_,sgabeg+18328
	.globl	 ktcsol_
	.set	ktcsol_,sgabeg+18332
	.globl	 ktcmtw_
	.set	ktcmtw_,sgabeg+18480
	.globl	 ktcxbt_
	.set	ktcxbt_,sgabeg+18484
	.globl	 ktcsga_
	.set	ktcsga_,sgabeg+18488
	.globl	 ktcso01_
	.set	ktcso01_,sgabeg+18504
	.globl	 ktcso02_
	.set	ktcso02_,sgabeg+18508
	.globl	 ktctx01_
	.set	ktctx01_,sgabeg+18512
	.globl	 ktstlt_
	.set	ktstlt_,sgabeg+18516
	.globl	 ktstud_
	.set	ktstud_,sgabeg+18664
	.globl	 ktstlr_
	.set	ktstlr_,sgabeg+18668
	.globl	 ktstl01_
	.set	ktstl01_,sgabeg+18676
	.globl	 ktstl02_
	.set	ktstl02_,sgabeg+18680
	.globl	 ktstl03_
	.set	ktstl03_,sgabeg+18684
	.globl	 ktstl04_
	.set	ktstl04_,sgabeg+18688
	.globl	 ktstl05_
	.set	ktstl05_,sgabeg+18692
	.globl	 ktstl06_
	.set	ktstl06_,sgabeg+18696
	.globl	 ktstl07_
	.set	ktstl07_,sgabeg+18700
	.globl	 ktstl08_
	.set	ktstl08_,sgabeg+18704
	.globl	 ktstl09_
	.set	ktstl09_,sgabeg+18708
	.globl	 ktstl10_
	.set	ktstl10_,sgabeg+18712
	.globl	 ktstl11_
	.set	ktstl11_,sgabeg+18716
	.globl	 ktstl12_
	.set	ktstl12_,sgabeg+18720
	.globl	 ktstl13_
	.set	ktstl13_,sgabeg+18724
	.globl	 ktstl14_
	.set	ktstl14_,sgabeg+18728
	.globl	 ktstl15_
	.set	ktstl15_,sgabeg+18732
	.globl	 ktstl16_
	.set	ktstl16_,sgabeg+18736
	.globl	 ktstl17_
	.set	ktstl17_,sgabeg+18740
	.globl	 ktstl18_
	.set	ktstl18_,sgabeg+18744
	.globl	 ktstl19_
	.set	ktstl19_,sgabeg+18748
	.globl	 ktstl20_
	.set	ktstl20_,sgabeg+18752
	.globl	 ktstl21_
	.set	ktstl21_,sgabeg+18756
	.globl	 ktstl22_
	.set	ktstl22_,sgabeg+18760
	.globl	 ktstl23_
	.set	ktstl23_,sgabeg+18764
	.globl	 ktstl24_
	.set	ktstl24_,sgabeg+18768
	.globl	 ktssga_
	.set	ktssga_,sgabeg+18772
	.globl	 ktsssg_
	.set	ktsssg_,sgabeg+19004
	.globl	 ktsssr_
	.set	ktsssr_,sgabeg+19012
	.globl	 ktseam_
	.set	ktseam_,sgabeg+19020
	.globl	 ktsinm_
	.set	ktsinm_,sgabeg+19024
	.globl	 ktsmtf_
	.set	ktsmtf_,sgabeg+19028
	.globl	 ktugd_
	.set	ktugd_,sgabeg+19032
	.globl	 ktunfc_
	.set	ktunfc_,sgabeg+19156
	.globl	 ktulat_
	.set	ktulat_,sgabeg+19160
	.globl	 ktuld_
	.set	ktuld_,sgabeg+19308
	.globl	 ktuere_
	.set	ktuere_,sgabeg+19324
	.globl	 ktueex_
	.set	ktueex_,sgabeg+19328
	.globl	 ktuetx_
	.set	ktuetx_,sgabeg+19332
	.globl	 ktuetb_
	.set	ktuetb_,sgabeg+19336
	.globl	 ktumxc_
	.set	ktumxc_,sgabeg+19340
	.globl	 kturcs_
	.set	kturcs_,sgabeg+19344
	.globl	 ktuglk_
	.set	ktuglk_,sgabeg+19420
	.globl	 ktuclk_
	.set	ktuclk_,sgabeg+19428
	.globl	 ktuflk_
	.set	ktuflk_,sgabeg+19436
	.globl	 kturco_
	.set	kturco_,sgabeg+19444
	.globl	 ktufg_
	.set	ktufg_,sgabeg+19448
	.globl	 ktuft_
	.set	ktuft_,sgabeg+19452
	.globl	 ktubg_
	.set	ktubg_,sgabeg+19456
	.globl	 ktubt_
	.set	ktubt_,sgabeg+19460
	.globl	 ktuuct_
	.set	ktuuct_,sgabeg+19464
	.globl	 ktutct_
	.set	ktutct_,sgabeg+19468
	.globl	 ktuucb_
	.set	ktuucb_,sgabeg+19472
	.globl	 ktutcn_
	.set	ktutcn_,sgabeg+19476
	.globl	 ktutcl_
	.set	ktutcl_,sgabeg+19480
	.globl	 ktutcr_
	.set	ktutcr_,sgabeg+19484
	.globl	 ktutcb_
	.set	ktutcb_,sgabeg+19488
	.globl	 ktuurx_
	.set	ktuurx_,sgabeg+19492
	.globl	 ktutrx_
	.set	ktutrx_,sgabeg+19496
	.globl	 ktutlx_
	.set	ktutlx_,sgabeg+19500
	.globl	 ktutlc_
	.set	ktutlc_,sgabeg+19504
	.globl	 ktutld_
	.set	ktutld_,sgabeg+19508
	.globl	 ktugd01_
	.set	ktugd01_,sgabeg+19512
	.globl	 ktugd02_
	.set	ktugd02_,sgabeg+19516
	.globl	 ktugd03_
	.set	ktugd03_,sgabeg+19520
	.globl	 ktugd04_
	.set	ktugd04_,sgabeg+19524
	.globl	 ktugd05_
	.set	ktugd05_,sgabeg+19528
	.globl	 ktugd06_
	.set	ktugd06_,sgabeg+19532
	.globl	 ktugd07_
	.set	ktugd07_,sgabeg+19536
	.globl	 ktugd08_
	.set	ktugd08_,sgabeg+19540
	.globl	 ktugd09_
	.set	ktugd09_,sgabeg+19544
	.globl	 ktugd10_
	.set	ktugd10_,sgabeg+19548
	.globl	 ktugd11_
	.set	ktugd11_,sgabeg+19552
	.globl	 ktugd12_
	.set	ktugd12_,sgabeg+19556
	.globl	 ktugd13_
	.set	ktugd13_,sgabeg+19560
	.globl	 ktugd14_
	.set	ktugd14_,sgabeg+19564
	.globl	 ktugd15_
	.set	ktugd15_,sgabeg+19568
	.globl	 ktugd16_
	.set	ktugd16_,sgabeg+19572
	.globl	 ktugd17_
	.set	ktugd17_,sgabeg+19576
	.globl	 ktugd18_
	.set	ktugd18_,sgabeg+19580
	.globl	 ktugd19_
	.set	ktugd19_,sgabeg+19584
	.globl	 ktugd20_
	.set	ktugd20_,sgabeg+19588
	.globl	 ktugd21_
	.set	ktugd21_,sgabeg+19592
	.globl	 ktugd22_
	.set	ktugd22_,sgabeg+19596
	.globl	 kteunl_
	.set	kteunl_,sgabeg+19600
	.globl	 kttctro_
	.set	kttctro_,sgabeg+19616
	.globl	 kttctmp_
	.set	kttctmp_,sgabeg+19632
	.globl	 ktmsga_
	.set	ktmsga_,sgabeg+19648
	.globl	 ktmirs_
	.set	ktmirs_,sgabeg+19756
	.globl	 ktmiev_
	.set	ktmiev_,sgabeg+19760
	.globl	 ktmsce_
	.set	ktmsce_,sgabeg+19764
	.globl	 ktmste_
	.set	ktmste_,sgabeg+19768
	.globl	 ktmlat_
	.set	ktmlat_,sgabeg+19772
	.globl	 ktmsg01_
	.set	ktmsg01_,sgabeg+19920
	.globl	 ktmsg02_
	.set	ktmsg02_,sgabeg+19924
	.globl	 ktmprc_
	.set	ktmprc_,sgabeg+19928
	.globl	 ktmpo01_
	.set	ktmpo01_,sgabeg+20020
	.globl	 ktmpo02_
	.set	ktmpo02_,sgabeg+20024
	.globl	 ktmpo03_
	.set	ktmpo03_,sgabeg+20028
	.globl	 ktsfxct_
	.set	ktsfxct_,sgabeg+20032
	.globl	 kdtrunc_
	.set	kdtrunc_,sgabeg+20048
	.globl	 kdstss_
	.set	kdstss_,sgabeg+20064
	.globl	 kdstsl_
	.set	kdstsl_,sgabeg+20068
	.globl	 kdstsr_
	.set	kdstsr_,sgabeg+20072
	.globl	 kdstsc_
	.set	kdstsc_,sgabeg+20076
	.globl	 kdstsd_
	.set	kdstsd_,sgabeg+20080
	.globl	 kdsrws_
	.set	kdsrws_,sgabeg+20084
	.globl	 kdstsb_
	.set	kdstsb_,sgabeg+20088
	.globl	 kdsbri_
	.set	kdsbri_,sgabeg+20092
	.globl	 kdsbco_
	.set	kdsbco_,sgabeg+20096
	.globl	 kdscsi_
	.set	kdscsi_,sgabeg+20100
	.globl	 kdsbch_
	.set	kdsbch_,sgabeg+20104
	.globl	 kdnsns_
	.set	kdnsns_,sgabeg+20108
	.globl	 kdnsga_
	.set	kdnsga_,sgabeg+20112
	.globl	 kdnlch_
	.set	kdnlch_,sgabeg+20152
	.globl	 kdnblr_
	.set	kdnblr_,sgabeg+20300
	.globl	 kdnso01_
	.set	kdnso01_,sgabeg+20308
	.globl	 kdnso02_
	.set	kdnso02_,sgabeg+20312
	.globl	 kdnso03_
	.set	kdnso03_,sgabeg+20316
	.globl	 kdnso04_
	.set	kdnso04_,sgabeg+20320
	.globl	 kdnso05_
	.set	kdnso05_,sgabeg+20324
	.globl	 kdnso06_
	.set	kdnso06_,sgabeg+20328
	.globl	 kdnso07_
	.set	kdnso07_,sgabeg+20332
	.globl	 kdisrbb_
	.set	kdisrbb_,sgabeg+20336
	.globl	 kdinfb_
	.set	kdinfb_,sgabeg+20352
	.globl	 kdibix_
	.set	kdibix_,sgabeg+20368
	.globl	 kdiswk_
	.set	kdiswk_,sgabeg+20384
	.globl	 kdisae_
	.set	kdisae_,sgabeg+20388
	.globl	 kdcdce_
	.set	kdcdce_,sgabeg+20392
	.globl	 kdcimhs_
	.set	kdcimhs_,sgabeg+20396
	.globl	 kdcfhex_
	.set	kdcfhex_,sgabeg+20412
	.globl	 kqrcol_
	.set	kqrcol_,sgabeg+20428
	.globl	 kqrelk_
	.set	kqrelk_,sgabeg+20576
	.globl	 kqrglk_
	.set	kqrglk_,sgabeg+20580
	.globl	 kqrtim_
	.set	kqrtim_,sgabeg+20588
	.globl	 kqrsga_
	.set	kqrsga_,sgabeg+20596
	.globl	 kqreqt_
	.set	kqreqt_,sgabeg+24784
	.globl	 kqrpo01_
	.set	kqrpo01_,sgabeg+24788
	.globl	 kqrpo02_
	.set	kqrpo02_,sgabeg+24792
	.globl	 kqrpo03_
	.set	kqrpo03_,sgabeg+24796
	.globl	 kqrpo04_
	.set	kqrpo04_,sgabeg+24800
	.globl	 kqrpo05_
	.set	kqrpo05_,sgabeg+24804
	.globl	 kqrpo06_
	.set	kqrpo06_,sgabeg+24808
	.globl	 kqrpo07_
	.set	kqrpo07_,sgabeg+24812
	.globl	 kqrpo08_
	.set	kqrpo08_,sgabeg+24816
	.globl	 kqrpo09_
	.set	kqrpo09_,sgabeg+24820
	.globl	 kqrpo10_
	.set	kqrpo10_,sgabeg+24824
	.globl	 kqrpo11_
	.set	kqrpo11_,sgabeg+24828
	.globl	 kqrcl01_
	.set	kqrcl01_,sgabeg+24832
	.globl	 kqrcl02_
	.set	kqrcl02_,sgabeg+24836
	.globl	 kqrcl03_
	.set	kqrcl03_,sgabeg+24840
	.globl	 kqrcl04_
	.set	kqrcl04_,sgabeg+24844
	.globl	 kqrcl05_
	.set	kqrcl05_,sgabeg+24848
	.globl	 kqrcl06_
	.set	kqrcl06_,sgabeg+24852
	.globl	 kqrcl07_
	.set	kqrcl07_,sgabeg+24856
	.globl	 kqrcl08_
	.set	kqrcl08_,sgabeg+24860
	.globl	 kqrcl09_
	.set	kqrcl09_,sgabeg+24864
	.globl	 kqrcl10_
	.set	kqrcl10_,sgabeg+24868
	.globl	 kqrcl11_
	.set	kqrcl11_,sgabeg+24872
	.globl	 kqrcl12_
	.set	kqrcl12_,sgabeg+24876
	.globl	 kqrcl41_
	.set	kqrcl41_,sgabeg+24880
	.globl	 kqrcl13_
	.set	kqrcl13_,sgabeg+24884
	.globl	 kqrcl14_
	.set	kqrcl14_,sgabeg+24888
	.globl	 kqrcl15_
	.set	kqrcl15_,sgabeg+24892
	.globl	 kqrcl16_
	.set	kqrcl16_,sgabeg+24896
	.globl	 kqrcl17_
	.set	kqrcl17_,sgabeg+24900
	.globl	 kqrcl18_
	.set	kqrcl18_,sgabeg+24904
	.globl	 kqrcl19_
	.set	kqrcl19_,sgabeg+24908
	.globl	 kqrcl20_
	.set	kqrcl20_,sgabeg+24912
	.globl	 kqrcl21_
	.set	kqrcl21_,sgabeg+24916
	.globl	 kqrcl22_
	.set	kqrcl22_,sgabeg+24920
	.globl	 kqrcl23_
	.set	kqrcl23_,sgabeg+24924
	.globl	 kqrcl24_
	.set	kqrcl24_,sgabeg+24928
	.globl	 kqrcl25_
	.set	kqrcl25_,sgabeg+24932
	.globl	 kqrcl26_
	.set	kqrcl26_,sgabeg+24936
	.globl	 kqrcl27_
	.set	kqrcl27_,sgabeg+24940
	.globl	 kqrcl28_
	.set	kqrcl28_,sgabeg+24944
	.globl	 kqrcl29_
	.set	kqrcl29_,sgabeg+24948
	.globl	 kqrcl30_
	.set	kqrcl30_,sgabeg+24952
	.globl	 kqrcl31_
	.set	kqrcl31_,sgabeg+24956
	.globl	 kqrcl32_
	.set	kqrcl32_,sgabeg+24960
	.globl	 kqrcl33_
	.set	kqrcl33_,sgabeg+24964
	.globl	 kqrcl34_
	.set	kqrcl34_,sgabeg+24968
	.globl	 kqrcl35_
	.set	kqrcl35_,sgabeg+24972
	.globl	 kqrcl36_
	.set	kqrcl36_,sgabeg+24976
	.globl	 kqrcl37_
	.set	kqrcl37_,sgabeg+24980
	.globl	 kqrcl38_
	.set	kqrcl38_,sgabeg+24984
	.globl	 kqrcl39_
	.set	kqrcl39_,sgabeg+24988
	.globl	 kqrcl40_
	.set	kqrcl40_,sgabeg+24992
	.globl	 kqlfl01_
	.set	kqlfl01_,sgabeg+24996
	.globl	 kqlmpn_
	.set	kqlmpn_,sgabeg+25000
	.globl	 kqlmin_
	.set	kqlmin_,sgabeg+25008
	.globl	 kqlmac_
	.set	kqlmac_,sgabeg+25016
	.globl	 kqlmp01_
	.set	kqlmp01_,sgabeg+25024
	.globl	 kqlmp02_
	.set	kqlmp02_,sgabeg+25028
	.globl	 kqlmp03_
	.set	kqlmp03_,sgabeg+25032
	.globl	 kqlmp04_
	.set	kqlmp04_,sgabeg+25036
	.globl	 kqlml01_
	.set	kqlml01_,sgabeg+25040
	.globl	 kqlml02_
	.set	kqlml02_,sgabeg+25044
	.globl	 kqlml03_
	.set	kqlml03_,sgabeg+25048
	.globl	 kqlml04_
	.set	kqlml04_,sgabeg+25052
	.globl	 kqlml05_
	.set	kqlml05_,sgabeg+25056
	.globl	 kqlml06_
	.set	kqlml06_,sgabeg+25060
	.globl	 kqlml07_
	.set	kqlml07_,sgabeg+25064
	.globl	 kqlml08_
	.set	kqlml08_,sgabeg+25068
	.globl	 kqlmpo1_
	.set	kqlmpo1_,sgabeg+25072
	.globl	 kqlmpo2_
	.set	kqlmpo2_,sgabeg+25076
	.globl	 kqlmpo3_
	.set	kqlmpo3_,sgabeg+25080
	.globl	 kqlmpo4_
	.set	kqlmpo4_,sgabeg+25084
	.globl	 kzdla01_
	.set	kzdla01_,sgabeg+25088
	.globl	 kzdla02_
	.set	kzdla02_,sgabeg+25092
	.globl	 kzdla03_
	.set	kzdla03_,sgabeg+25096
	.globl	 kzsban_
	.set	kzsban_,sgabeg+25100
	.globl	 kzsrl_o
	.set	kzsrl_o,sgabeg+25104
	.globl	 kzslr_o
	.set	kzslr_o,sgabeg+25108
	.globl	 kzsla01_
	.set	kzsla01_,sgabeg+25112
	.globl	 kzsla02_
	.set	kzsla02_,sgabeg+25116
	.globl	 kzsla03_
	.set	kzsla03_,sgabeg+25120
	.globl	 kzsla04_
	.set	kzsla04_,sgabeg+25124
	.globl	 kzrcol_
	.set	kzrcol_,sgabeg+25128
	.globl	 kzrcf01_
	.set	kzrcf01_,sgabeg+25276
	.globl	 kzrcf02_
	.set	kzrcf02_,sgabeg+25280
	.globl	 kzsrsg_
	.set	kzsrsg_,sgabeg+25284
	.globl	 kzulsg_
	.set	kzulsg_,sgabeg+25564
	.globl	 kzullt_
	.set	kzullt_,sgabeg+26604
	.globl	 kzullk_
	.set	kzullk_,sgabeg+26752
	.globl	 kzulla_
	.set	kzulla_,sgabeg+26756
	.globl	 kzuul01_
	.set	kzuul01_,sgabeg+26764
	.globl	 kzuul02_
	.set	kzuul02_,sgabeg+26768
	.globl	 kzuul03_
	.set	kzuul03_,sgabeg+26772
	.globl	 kzuul04_
	.set	kzuul04_,sgabeg+26776
	.globl	 kzulum_
	.set	kzulum_,sgabeg+26780
	.globl	 k2dgnm_
	.set	k2dgnm_,sgabeg+26784
	.globl	 k2gtab_
	.set	k2gtab_,sgabeg+26788
	.globl	 k2gflh_
	.set	k2gflh_,sgabeg+26828
	.globl	 k2gboo_
	.set	k2gboo_,sgabeg+26836
	.globl	 k2gflx_
	.set	k2gflx_,sgabeg+26840
	.globl	 k2gtex_
	.set	k2gtex_,sgabeg+26988
	.globl	 k2gtehx_
	.set	k2gtehx_,sgabeg+27136
	.globl	 k2gtb01_
	.set	k2gtb01_,sgabeg+27284
	.globl	 k2gfl01_
	.set	k2gfl01_,sgabeg+27288
	.globl	 k2gfl02_
	.set	k2gfl02_,sgabeg+27292
	.globl	 k2gfl03_
	.set	k2gfl03_,sgabeg+27296
	.globl	 k2vbkg_
	.set	k2vbkg_,sgabeg+27300
	.globl	 k2vwak_
	.set	k2vwak_,sgabeg+27392
	.globl	 k2vsht_
	.set	k2vsht_,sgabeg+27400
	.globl	 k2ievt_
	.set	k2ievt_,sgabeg+27408
	.globl	 k2ieeg_
	.set	k2ieeg_,sgabeg+27412
	.globl	 kghlat_
	.set	kghlat_,sgabeg+27416
	.globl	 kgllat_
	.set	kgllat_,sgabeg+27564
	.globl	 kglllt_
	.set	kglllt_,sgabeg+27712
	.globl	 kmmste_
	.set	kmmste_,sgabeg+27860
	.globl	 kmmsga_
	.set	kmmsga_,sgabeg+27864
	.globl	 kmmcfg_
	.set	kmmcfg_,sgabeg+27968
	.globl	 kmmtcn_
	.set	kmmtcn_,sgabeg+27972
	.globl	 kmmpd01_
	.set	kmmpd01_,sgabeg+27976
	.globl	 kmmpd02_
	.set	kmmpd02_,sgabeg+27980
	.globl	 kmmpd03_
	.set	kmmpd03_,sgabeg+27984
	.globl	 kmmpd04_
	.set	kmmpd04_,sgabeg+27988
	.globl	 kmmps01_
	.set	kmmps01_,sgabeg+27992
	.globl	 kmmps02_
	.set	kmmps02_,sgabeg+27996
	.globl	 kmcnvq_
	.set	kmcnvq_,sgabeg+28000
	.globl	 kmcque_
	.set	kmcque_,sgabeg+28004
	.globl	 kmcnvc_
	.set	kmcnvc_,sgabeg+28008
	.globl	 kmcvca_
	.set	kmcvca_,sgabeg+28012
	.globl	 kmcvcf_
	.set	kmcvcf_,sgabeg+28016
	.globl	 kmcblt_
	.set	kmcblt_,sgabeg+28020
	.globl	 kmcqlt_
	.set	kmcqlt_,sgabeg+28168
	.globl	 kmcalc_
	.set	kmcalc_,sgabeg+28316
	.globl	 kmcsce_
	.set	kmcsce_,sgabeg+28464
	.globl	 kmcvco_
	.set	kmcvco_,sgabeg+28468
	.globl	 kmcal01_
	.set	kmcal01_,sgabeg+28472
	.globl	 kmcal02_
	.set	kmcal02_,sgabeg+28476
	.globl	 kmcal03_
	.set	kmcal03_,sgabeg+28480
	.globl	 kmcal04_
	.set	kmcal04_,sgabeg+28484
	.globl	 kmcal05_
	.set	kmcal05_,sgabeg+28488
	.globl	 kmcal06_
	.set	kmcal06_,sgabeg+28492
	.globl	 kmcal07_
	.set	kmcal07_,sgabeg+28496
	.globl	 kmcql01_
	.set	kmcql01_,sgabeg+28500
	.globl	 kmcql02_
	.set	kmcql02_,sgabeg+28504
	.globl	 kmcql03_
	.set	kmcql03_,sgabeg+28508
	.globl	 kmccl01_
	.set	kmccl01_,sgabeg+28512
	.globl	 kmccl02_
	.set	kmccl02_,sgabeg+28516
	.globl	 kmccl03_
	.set	kmccl03_,sgabeg+28520
	.globl	 kmccl04_
	.set	kmccl04_,sgabeg+28524
	.globl	 kmccl05_
	.set	kmccl05_,sgabeg+28528
	.globl	 kmccl06_
	.set	kmccl06_,sgabeg+28532
	.globl	 kmccl07_
	.set	kmccl07_,sgabeg+28536
	.globl	 kmccl08_
	.set	kmccl08_,sgabeg+28540
	.globl	 kmccl09_
	.set	kmccl09_,sgabeg+28544
	.globl	 kmccl10_
	.set	kmccl10_,sgabeg+28548
	.globl	 kmccl11_
	.set	kmccl11_,sgabeg+28552
	.globl	 kmccl12_
	.set	kmccl12_,sgabeg+28556
	.globl	 kmccl13_
	.set	kmccl13_,sgabeg+28560
	.globl	 kmccl14_
	.set	kmccl14_,sgabeg+28564
	.globl	 kmccl15_
	.set	kmccl15_,sgabeg+28568
	.globl	 kmccl16_
	.set	kmccl16_,sgabeg+28572
	.globl	 kmcal17_
	.set	kmcal17_,sgabeg+28576
	.globl	 kmcbl01_
	.set	kmcbl01_,sgabeg+28580
	.globl	 kmcps1_
	.set	kmcps1_,sgabeg+28584
	.globl	 kmcps2_
	.set	kmcps2_,sgabeg+28588
	.globl	 kmcps3_
	.set	kmcps3_,sgabeg+28592
	.globl	 kmcps4_
	.set	kmcps4_,sgabeg+28596
	.globl	 kmcps5_
	.set	kmcps5_,sgabeg+28600
	.globl	 kmcps6_
	.set	kmcps6_,sgabeg+28604
	.globl	 kmcps7_
	.set	kmcps7_,sgabeg+28608
	.globl	 kmcps8_
	.set	kmcps8_,sgabeg+28612
	.globl	 kmcps9_
	.set	kmcps9_,sgabeg+28616
	.globl	 kmcps10_
	.set	kmcps10_,sgabeg+28620
	.globl	 kmcps11_
	.set	kmcps11_,sgabeg+28624
	.globl	 kmdtwe_
	.set	kmdtwe_,sgabeg+28628
	.globl	 kmdpo01_
	.set	kmdpo01_,sgabeg+28632
	.globl	 sgadci_
	.set	sgadci_,sgabeg+28636
	.globl	 sgadcs_
	.set	sgadcs_,sgabeg+28640
	.globl	 sgakwa_
	.set	sgakwa_,sgabeg+28644
	.globl	 sgaaka_
	.set	sgaaka_,sgabeg+28700
	.globl	 sgaflg_
	.set	sgaflg_,sgabeg+28756
	.globl	 sgafxd_
	.set	sgafxd_,sgabeg+28760
	.globl	 sgamcs_
	.set	sgamcs_,sgabeg+28772
	.globl	 sganct_
	.set	sganct_,sgabeg+28776
	.globl	 sgastp_
	.set	sgastp_,sgabeg+28780
	.globl	 sgavsn_
	.set	sgavsn_,sgabeg+28820
	.globl	 sgavss_
	.set	sgavss_,sgabeg+28824
	.globl	 sgabtf_
	.set	sgabtf_,sgabeg+28884
	.globl	 prstic_
	.set	prstic_,sgabeg+28888
	.globl	 prstie_
	.set	prstie_,sgabeg+28892
	.globl	 prscnt_
	.set	prscnt_,sgabeg+28896
	.globl	 execnt_
	.set	execnt_,sgabeg+28900
	.globl	 opissbc_
	.set	opissbc_,sgabeg+28904
	.globl	 opisrbc_
	.set	opisrbc_,sgabeg+28908
	.globl	 opisrtc_
	.set	opisrtc_,sgabeg+28912
	.globl	 opissbr_
	.set	opissbr_,sgabeg+28916
	.globl	 opisrbr_
	.set	opisrbr_,sgabeg+28920
	.globl	 opisrtr_
	.set	opisrtr_,sgabeg+28924
	.globl	 sgannc_
	.set	sgannc_,sgabeg+28928
	.globl	 opiestm_
	.set	opiestm_,sgabeg+28932
	.globl	 opiesdc_
	.set	opiesdc_,sgabeg+28936
	.globl	 opiesdr_
	.set	opiesdr_,sgabeg+28940
	.globl	 opiesac_
	.set	opiesac_,sgabeg+28944
	.globl	 opiesar_
	.set	opiesar_,sgabeg+28948
	.globl	 opiermc_
	.set	opiermc_,sgabeg+28952
	.globl	 opierac_
	.set	opierac_,sgabeg+28956
	.globl	 opiermr_
	.set	opiermr_,sgabeg+28960
	.globl	 opierar_
	.set	opierar_,sgabeg+28964
	.globl	 opieopc_
	.set	opieopc_,sgabeg+28968
	.globl	 opieopr_
	.set	opieopr_,sgabeg+28972
	.globl	 secla01_
	.set	secla01_,sgabeg+28976
	.globl	 pgaau_o
	.set	pgaau_o,sgabeg+28980
	.globl	 pgase_o
	.set	pgase_o,sgabeg+28984
	.globl	 sorsho_
	.set	sorsho_,sgabeg+28988
	.globl	 sorlon_
	.set	sorlon_,sgabeg+28992
	.globl	 sorrws_
	.set	sorrws_,sgabeg+28996
	.globl	 psdwev_
	.set	psdwev_,sgabeg+29000
	.globl	 atbcdl_
	.set	atbcdl_,sgabeg+29004
	.globl	 klcslt_
	.set	klcslt_,sgabeg+29020
	.globl	 klcslo_
	.set	klcslo_,sgabeg+29168
	.globl	 klcsobl_
	.set	klcsobl_,sgabeg+29184
	.globl	 klcsl01_
	.set	klcsl01_,sgabeg+29188
	.globl	 klcsl02_
	.set	klcsl02_,sgabeg+29192
	.globl	 seqsga_
	.set	seqsga_,sgabeg+29196
	.globl	 kksfst_
	.set	kksfst_,sgabeg+29252
	.globl	 kkssav_
	.set	kkssav_,sgabeg+29256
	.globl	 kkshit_
	.set	kkshit_,sgabeg+29260
	.globl	 kkscnt_
	.set	kkscnt_,sgabeg+29264
	.globl	 kksevnt_
	.set	kksevnt_,sgabeg+29268
	.globl	 kksla01_
	.set	kksla01_,sgabeg+29272
	.globl	 kkxrds_
	.set	kkxrds_,sgabeg+29276
	.globl	 kkjsre_
	.set	kkjsre_,sgabeg+29280
	.globl	 kkjnsrp_
	.set	kkjnsrp_,sgabeg+29284
	.globl	 kkjkcar_
	.set	kkjkcar_,sgabeg+29288
	.globl	 kkjsri_
	.set	kkjsri_,sgabeg+29292
	.globl	 kkjsrp0_
	.set	kkjsrp0_,sgabeg+29296
	.globl	 kkjsrp1_
	.set	kkjsrp1_,sgabeg+29388
	.globl	 kkjsrp2_
	.set	kkjsrp2_,sgabeg+29480
	.globl	 kkjsrp3_
	.set	kkjsrp3_,sgabeg+29572
	.globl	 kkjsrp4_
	.set	kkjsrp4_,sgabeg+29664
	.globl	 kkjsrp5_
	.set	kkjsrp5_,sgabeg+29756
	.globl	 kkjsrp6_
	.set	kkjsrp6_,sgabeg+29848
	.globl	 kkjsrp7_
	.set	kkjsrp7_,sgabeg+29940
	.globl	 kkjsrp8_
	.set	kkjsrp8_,sgabeg+30032
	.globl	 kkjsrp9_
	.set	kkjsrp9_,sgabeg+30124
	.globl	 kkjsrpa_
	.set	kkjsrpa_,sgabeg+30216
	.globl	 kkjsrpb_
	.set	kkjsrpb_,sgabeg+30308
	.globl	 kkjsrpc_
	.set	kkjsrpc_,sgabeg+30400
	.globl	 kkjsrpd_
	.set	kkjsrpd_,sgabeg+30492
	.globl	 kkjsrpe_
	.set	kkjsrpe_,sgabeg+30584
	.globl	 kkjsrpf_
	.set	kkjsrpf_,sgabeg+30676
	.globl	 kkjsrpg_
	.set	kkjsrpg_,sgabeg+30768
	.globl	 kkjsrph_
	.set	kkjsrph_,sgabeg+30860
	.globl	 kkjsrpi_
	.set	kkjsrpi_,sgabeg+30952
	.globl	 kkjsrpj_
	.set	kkjsrpj_,sgabeg+31044
	.globl	 kkjsrpk_
	.set	kkjsrpk_,sgabeg+31136
	.globl	 kkjsrpl_
	.set	kkjsrpl_,sgabeg+31228
	.globl	 kkjsrpm_
	.set	kkjsrpm_,sgabeg+31320
	.globl	 kkjsrpn_
	.set	kkjsrpn_,sgabeg+31412
	.globl	 kkjsrpo_
	.set	kkjsrpo_,sgabeg+31504
	.globl	 kkjsrpp_
	.set	kkjsrpp_,sgabeg+31596
	.globl	 kkjsrpq_
	.set	kkjsrpq_,sgabeg+31688
	.globl	 kkjsrpr_
	.set	kkjsrpr_,sgabeg+31780
	.globl	 kkjsrps_
	.set	kkjsrps_,sgabeg+31872
	.globl	 kkjsrpt_
	.set	kkjsrpt_,sgabeg+31964
	.globl	 kkjsrpu_
	.set	kkjsrpu_,sgabeg+32056
	.globl	 kkjsrpv_
	.set	kkjsrpv_,sgabeg+32148
	.globl	 kkjsrpw_
	.set	kkjsrpw_,sgabeg+32240
	.globl	 kkjsrpx_
	.set	kkjsrpx_,sgabeg+32332
	.globl	 kkjsrpy_
	.set	kkjsrpy_,sgabeg+32424
	.globl	 kkjsrpz_
	.set	kkjsrpz_,sgabeg+32516
	.globl	 kkjshta_
	.set	kkjshta_,sgabeg+32608
	.globl	 kkjssra_
	.set	kkjssra_,sgabeg+32616
	.globl	 kkzctus_
	.set	kkzctus_,sgabeg+32624
	.globl	 kksact_
	.set	kksact_,sgabeg+32640
	.globl	 kkxpge_
	.set	kkxpge_,sgabeg+32644
	.globl	 kkxppu_
	.set	kkxppu_,sgabeg+32648
	.globl	 kkfrsga_
	.set	kkfrsga_,sgabeg+32652
	.globl	 kktctmt_
	.set	kktctmt_,sgabeg+32664
	.globl	 kkbtru_
	.set	kkbtru_,sgabeg+32680
	.globl	 kxspwh_
	.set	kxspwh_,sgabeg+32696
	.globl	 kxspbh_
	.set	kxspbh_,sgabeg+32788
	.globl	 kxfpge_
	.set	kxfpge_,sgabeg+32880
	.globl	 kxfpsga_
	.set	kxfpsga_,sgabeg+32888
	.globl	 kxfpncl_
	.set	kxfpncl_,sgabeg+33008
	.globl	 kxfpncm_
	.set	kxfpncm_,sgabeg+33012
	.globl	 kxfpncd_
	.set	kxfpncd_,sgabeg+33016
	.globl	 kxfpcst_
	.set	kxfpcst_,sgabeg+33020
	.globl	 kxfpcss_
	.set	kxfpcss_,sgabeg+33272
	.globl	 kxfpcms_
	.set	kxfpcms_,sgabeg+33444
	.globl	 kxfpsms_
	.set	kxfpsms_,sgabeg+33448
	.globl	 kxfpcds_
	.set	kxfpcds_,sgabeg+33452
	.globl	 kxfpsds_
	.set	kxfpsds_,sgabeg+33456
	.globl	 kxfpqu_
	.set	kxfpqu_,sgabeg+33460
	.globl	 kxfpre_
	.set	kxfpre_,sgabeg+33464
	.globl	 kxfppl_
	.set	kxfppl_,sgabeg+33468
	.globl	 kxfpfl_
	.set	kxfpfl_,sgabeg+33616
	.globl	 kxfpel_
	.set	kxfpel_,sgabeg+33764
	.globl	 kxfpql_
	.set	kxfpql_,sgabeg+33912
	.globl	 kxfprl_
	.set	kxfprl_,sgabeg+34060
	.globl	 kxfpsl_
	.set	kxfpsl_,sgabeg+34208
	.globl	 kxfprle_
	.set	kxfprle_,sgabeg+34356
	.globl	 kxfpdqe_
	.set	kxfpdqe_,sgabeg+34360
	.globl	 kxfpshe_
	.set	kxfpshe_,sgabeg+34364
	.globl	 kxfpcse_
	.set	kxfpcse_,sgabeg+34368
	.globl	 kxfpsge_
	.set	kxfpsge_,sgabeg+34372
	.globl	 kxfpmtj_
	.set	kxfpmtj_,sgabeg+34376
	.globl	 kxfpmtr_
	.set	kxfpmtr_,sgabeg+34380
	.globl	 kxfpmts_
	.set	kxfpmts_,sgabeg+34384
	.globl	 kxfpmtp_
	.set	kxfpmtp_,sgabeg+34388
	.globl	 kxfpmte_
	.set	kxfpmte_,sgabeg+34392
	.globl	 kxfpmtx_
	.set	kxfpmtx_,sgabeg+34396
	.globl	 kxfpmrs_
	.set	kxfpmrs_,sgabeg+34400
	.globl	 kxfpdrj_
	.set	kxfpdrj_,sgabeg+34404
	.globl	 kxfpdrr_
	.set	kxfpdrr_,sgabeg+34408
	.globl	 kxfpdrg_
	.set	kxfpdrg_,sgabeg+34412
	.globl	 kxfpdrf_
	.set	kxfpdrf_,sgabeg+34416
	.globl	 kxfpdre_
	.set	kxfpdre_,sgabeg+34420
	.globl	 kxfpdrt_
	.set	kxfpdrt_,sgabeg+34424
	.globl	 kxfpdrs_
	.set	kxfpdrs_,sgabeg+34428
	.globl	 kxfpf01_
	.set	kxfpf01_,sgabeg+34432
	.globl	 kxfpf02_
	.set	kxfpf02_,sgabeg+34436
	.globl	 kxfpf03_
	.set	kxfpf03_,sgabeg+34440
	.globl	 kxfpf04_
	.set	kxfpf04_,sgabeg+34444
	.globl	 kxfpf05_
	.set	kxfpf05_,sgabeg+34448
	.globl	 kxfpf06_
	.set	kxfpf06_,sgabeg+34452
	.globl	 kxfpe01_
	.set	kxfpe01_,sgabeg+34456
	.globl	 kxfpe02_
	.set	kxfpe02_,sgabeg+34460
	.globl	 kxfpe03_
	.set	kxfpe03_,sgabeg+34464
	.globl	 kxfpe04_
	.set	kxfpe04_,sgabeg+34468
	.globl	 kxfpr01_
	.set	kxfpr01_,sgabeg+34472
	.globl	 kxfpr02_
	.set	kxfpr02_,sgabeg+34476
	.globl	 kxfpr03_
	.set	kxfpr03_,sgabeg+34480
	.globl	 kxfpr04_
	.set	kxfpr04_,sgabeg+34484
	.globl	 kxfpr05_
	.set	kxfpr05_,sgabeg+34488
	.globl	 kxfpr06_
	.set	kxfpr06_,sgabeg+34492
	.globl	 kxfpr07_
	.set	kxfpr07_,sgabeg+34496
	.globl	 kxfpr08_
	.set	kxfpr08_,sgabeg+34500
	.globl	 kxfpr09_
	.set	kxfpr09_,sgabeg+34504
	.globl	 kxfpr10_
	.set	kxfpr10_,sgabeg+34508
	.globl	 kxfpr11_
	.set	kxfpr11_,sgabeg+34512
	.globl	 kxfpr12_
	.set	kxfpr12_,sgabeg+34516
	.globl	 kxfpr13_
	.set	kxfpr13_,sgabeg+34520
	.globl	 kxfpr14_
	.set	kxfpr14_,sgabeg+34524
	.globl	 kxfpr15_
	.set	kxfpr15_,sgabeg+34528
	.globl	 kxfpp01_
	.set	kxfpp01_,sgabeg+34532
	.globl	 kxfpp02_
	.set	kxfpp02_,sgabeg+34536
	.globl	 kxfpp03_
	.set	kxfpp03_,sgabeg+34540
	.globl	 kxfpp04_
	.set	kxfpp04_,sgabeg+34544
	.globl	 kxfpp05_
	.set	kxfpp05_,sgabeg+34548
	.globl	 kxfpc01_
	.set	kxfpc01_,sgabeg+34552
	.globl	 kxfpc02_
	.set	kxfpc02_,sgabeg+34556
	.globl	 kxfpc03_
	.set	kxfpc03_,sgabeg+34560
	.globl	 kxfpq01_
	.set	kxfpq01_,sgabeg+34564
	.globl	 kxfpq02_
	.set	kxfpq02_,sgabeg+34568
	.globl	 kxfps01_
	.set	kxfps01_,sgabeg+34572
	.globl	 kxfppo1_
	.set	kxfppo1_,sgabeg+34576
	.globl	 kxfppo2_
	.set	kxfppo2_,sgabeg+34580
	.globl	 kxfppo3_
	.set	kxfppo3_,sgabeg+34584
	.globl	 kxfppo4_
	.set	kxfppo4_,sgabeg+34588
	.globl	 kxfppo5_
	.set	kxfppo5_,sgabeg+34592
	.globl	 kxfppo6_
	.set	kxfppo6_,sgabeg+34596
	.globl	 kxfppo7_
	.set	kxfppo7_,sgabeg+34600
	.globl	 kxfpbl_
	.set	kxfpbl_,sgabeg+34604
	.globl	 kxfpb01_
	.set	kxfpb01_,sgabeg+34752
	.globl	 kxfpb02_
	.set	kxfpb02_,sgabeg+34756
	.globl	 kxfpb03_
	.set	kxfpb03_,sgabeg+34760
	.globl	 kxfxcl_
	.set	kxfxcl_,sgabeg+34764
	.globl	 kxfxmtn_
	.set	kxfxmtn_,sgabeg+34768
	.globl	 kxfxmtp_
	.set	kxfxmtp_,sgabeg+34772
	.globl	 kxfxmte_
	.set	kxfxmte_,sgabeg+34776
	.globl	 kxfxmtr_
	.set	kxfxmtr_,sgabeg+34780
	.globl	 kxfxmtpf_
	.set	kxfxmtpf_,sgabeg+34784
	.globl	 kxfxmtef_
	.set	kxfxmtef_,sgabeg+34788
	.globl	 kxfxmtrf_
	.set	kxfxmtrf_,sgabeg+34792
	.globl	 kxfxmto_
	.set	kxfxmto_,sgabeg+34796
	.globl	 kxfxmtls_
	.set	kxfxmtls_,sgabeg+34800
	.globl	 kxfxmtlr_
	.set	kxfxmtlr_,sgabeg+34804
	.globl	 kxfxmtlp_
	.set	kxfxmtlp_,sgabeg+34808
	.globl	 kxfxmtld_
	.set	kxfxmtld_,sgabeg+34812
	.globl	 kxfxmtc_
	.set	kxfxmtc_,sgabeg+34816
	.globl	 kxfxdrf_
	.set	kxfxdrf_,sgabeg+34820
	.globl	 kxfxdrp_
	.set	kxfxdrp_,sgabeg+34824
	.globl	 kxfxdrc_
	.set	kxfxdrc_,sgabeg+34828
	.globl	 kxfxdrs_
	.set	kxfxdrs_,sgabeg+34832
	.globl	 kxfqmth_
	.set	kxfqmth_,sgabeg+34836
	.globl	 kxfqmtr_
	.set	kxfqmtr_,sgabeg+34840
	.globl	 kxfqmtrs_
	.set	kxfqmtrs_,sgabeg+34844
	.globl	 kxfqmtrk_
	.set	kxfqmtrk_,sgabeg+34848
	.globl	 kxfqmto_
	.set	kxfqmto_,sgabeg+34852
	.globl	 kxfqmtn_
	.set	kxfqmtn_,sgabeg+34856
	.globl	 kxfqmtd_
	.set	kxfqmtd_,sgabeg+34860
	.globl	 kxfqmtb_
	.set	kxfqmtb_,sgabeg+34864
	.globl	 kxfqmtu_
	.set	kxfqmtu_,sgabeg+34868
	.globl	 kxfqdrd_
	.set	kxfqdrd_,sgabeg+34872
	.globl	 kxfqdrds_
	.set	kxfqdrds_,sgabeg+34876
	.globl	 kxfqdrr_
	.set	kxfqdrr_,sgabeg+34880
	.globl	 kxfqdrk_
	.set	kxfqdrk_,sgabeg+34884
	.globl	 kxfqdrc_
	.set	kxfqdrc_,sgabeg+34888
	.globl	 kxfrafon_
	.set	kxfrafon_,sgabeg+34892
	.globl	 ksimndname_
	.set	ksimndname_,sgabeg+34896
	.globl	 ksxafsq_
	.set	ksxafsq_,sgabeg+34900
	.globl	 ksxafib_
	.set	ksxafib_,sgabeg+34904
	.globl	 ksxagdd_
	.set	ksxagdd_,sgabeg+34908
	.globl	 ksxagnm_
	.set	ksxagnm_,sgabeg+34912
	.globl	 ksxacfa_
	.set	ksxacfa_,sgabeg+34916
	.globl	 ksxatnode_
	.set	ksxatnode_,sgabeg+34920
	.globl	 ksxadvi_
	.set	ksxadvi_,sgabeg+34924
	.globl	 ksxa01_
	.set	ksxa01_,sgabeg+35072
	.globl	 kxfr01_
	.set	kxfr01_,sgabeg+35076
	.globl	 sksawt_
	.set	sksawt_,sgabeg+35080
	.globl	 scgast_
	.set	scgast_,sgabeg+35084
	.globl	 sfaowt_
	.set	sfaowt_,sgabeg+35088
	.globl	 sfslwt_
	.set	sfslwt_,sgabeg+35092
	.globl	 sdsmdb_
	.set	sdsmdb_,sgabeg+35096
	.globl	 sdsga_max_seq_
	.set	sdsga_max_seq_,sgabeg+35100
	.globl	 sdsga_unlimit_
	.set	sdsga_unlimit_,sgabeg+35104
	.globl	 sdsddd_
	.set	sdsddd_,sgabeg+35108
	.globl	 sdsudd_
	.set	sdsudd_,sgabeg+35364
	.globl	 sdscdd_
	.set	sdscdd_,sgabeg+35620
	.globl	 sdalfn_
	.set	sdalfn_,sgabeg+35876
	.globl	 sdsgai_
	.set	sdsgai_,sgabeg+36132
	.globl	 sdtgte_
	.set	sdtgte_,sgabeg+36136
	.globl	 sdtrst_
	.set	sdtrst_,sgabeg+36140
	.globl	 sdtseq_
	.set	sdtseq_,sgabeg+36144
	.globl	 sdtscr_
	.set	sdtscr_,sgabeg+36148
	.globl	 scggid_
	.set	scggid_,sgabeg+36152
	.globl	 scsmwt_
	.set	scsmwt_,sgabeg+36156
	.globl	 sfasyn_
	.set	sfasyn_,sgabeg+36160
	.globl	 sfsccf_
	.set	sfsccf_,sgabeg+36164
	.globl	 smdbp_
	.set	smdbp_,sgabeg+36168
	.globl	 smdbbk_
	.set	smdbbk_,sgabeg+36228
	.globl	 smdbps_
	.set	smdbps_,sgabeg+36232
	.globl	 smdbsz_
	.set	smdbsz_,sgabeg+36236
	.globl	 smdblk_
	.set	smdblk_,sgabeg+36296
	.globl	 smdbns_
	.set	smdbns_,sgabeg+36356
	.globl	 smrdp_
	.set	smrdp_,sgabeg+36360
	.globl	 smrdbk_
	.set	smrdbk_,sgabeg+36420
	.globl	 smrdps_
	.set	smrdps_,sgabeg+36424
	.globl	 smsgsz_
	.set	smsgsz_,sgabeg+36428
	.globl	 smndbb_
	.set	smndbb_,sgabeg+36432
	.globl	 smsvad_
	.set	smsvad_,sgabeg+36436
	.globl	 smsvsz_
	.set	smsvsz_,sgabeg+36496
	.globl	 smsvfl_
	.set	smsvfl_,sgabeg+36556
	.globl	 ssmsdef_
	.set	ssmsdef_,sgabeg+36616
	.globl	 spwupw_
	.set	spwupw_,sgabeg+36908
	.globl	 sppwfn_
	.set	sppwfn_,sgabeg+36912
	.globl	 spsps_
	.set	spsps_,sgabeg+37168
	.globl	 spsem_
	.set	spsem_,sgabeg+37172
	.globl	 spsetnum_
	.set	spsetnum_,sgabeg+37212
	.globl	 sspdcrpid_
	.set	sspdcrpid_,sgabeg+37216
	.globl	 spdbabort_
	.set	spdbabort_,sgabeg+37220
	.globl	 sptintrval_
	.set	sptintrval_,sgabeg+37224
	.globl	 sptininst_
	.set	sptininst_,sgabeg+37228
	.globl	 ssfaorqa_
	.set	ssfaorqa_,sgabeg+37232
	.globl	 ssfaonws_
	.set	ssfaonws_,sgabeg+37236
	.globl	 ssfaoofg_
	.set	ssfaoofg_,sgabeg+37240
	.globl	 ssfaofbs_
	.set	ssfaofbs_,sgabeg+37244
	.globl	 ssfaow1_
	.set	ssfaow1_,sgabeg+37248
	.globl	 ssfaow2_
	.set	ssfaow2_,sgabeg+37340
	.globl	 ssfaow3_
	.set	ssfaow3_,sgabeg+37432
	.globl	 ssfaow4_
	.set	ssfaow4_,sgabeg+37524
	.globl	 ssfaow5_
	.set	ssfaow5_,sgabeg+37616
	.globl	 ssfaow6_
	.set	ssfaow6_,sgabeg+37708
	.globl	 ssfaow7_
	.set	ssfaow7_,sgabeg+37800
	.globl	 ssfaow8_
	.set	ssfaow8_,sgabeg+37892
	.globl	 ssfaow9_
	.set	ssfaow9_,sgabeg+37984
	.globl	 ssfaow10_
	.set	ssfaow10_,sgabeg+38076
	.globl	 ssfaow11_
	.set	ssfaow11_,sgabeg+38168
	.globl	 ssfaow12_
	.set	ssfaow12_,sgabeg+38260
	.globl	 ssfaow13_
	.set	ssfaow13_,sgabeg+38352
	.globl	 ssfaow14_
	.set	ssfaow14_,sgabeg+38444
	.globl	 ssfaow15_
	.set	ssfaow15_,sgabeg+38536
	.globl	 ssfaow16_
	.set	ssfaow16_,sgabeg+38628
	.globl	 ssfaow17_
	.set	ssfaow17_,sgabeg+38720
	.globl	 ssfaow18_
	.set	ssfaow18_,sgabeg+38812
	.globl	 ssfaow19_
	.set	ssfaow19_,sgabeg+38904
	.globl	 ssfaow20_
	.set	ssfaow20_,sgabeg+38996
	.globl	 ssfaow21_
	.set	ssfaow21_,sgabeg+39088
	.globl	 ssfaow22_
	.set	ssfaow22_,sgabeg+39180
	.globl	 ssfaow23_
	.set	ssfaow23_,sgabeg+39272
	.globl	 ssfaow24_
	.set	ssfaow24_,sgabeg+39364
	.globl	 ssfaow25_
	.set	ssfaow25_,sgabeg+39456
	.globl	 ssfaow26_
	.set	ssfaow26_,sgabeg+39548
	.globl	 ssfaow27_
	.set	ssfaow27_,sgabeg+39640
	.globl	 ssfaow28_
	.set	ssfaow28_,sgabeg+39732
	.globl	 ssfaow29_
	.set	ssfaow29_,sgabeg+39824
	.globl	 ssfaow30_
	.set	ssfaow30_,sgabeg+39916
	.globl	 ssfaow31_
	.set	ssfaow31_,sgabeg+40008
	.globl	 ssfaow32_
	.set	ssfaow32_,sgabeg+40100
	.globl	 ssfaow33_
	.set	ssfaow33_,sgabeg+40192
	.globl	 ssfaow34_
	.set	ssfaow34_,sgabeg+40284
	.globl	 ssfaow35_
	.set	ssfaow35_,sgabeg+40376
	.globl	 ssfaow36_
	.set	ssfaow36_,sgabeg+40468
	.globl	 ssfaow37_
	.set	ssfaow37_,sgabeg+40560
	.globl	 ssfaow38_
	.set	ssfaow38_,sgabeg+40652
	.globl	 ssfaow39_
	.set	ssfaow39_,sgabeg+40744
	.globl	 ssfaow40_
	.set	ssfaow40_,sgabeg+40836
	.globl	 ssfaow41_
	.set	ssfaow41_,sgabeg+40928
	.globl	 ssfaow42_
	.set	ssfaow42_,sgabeg+41020
	.globl	 ssfaow43_
	.set	ssfaow43_,sgabeg+41112
	.globl	 ssfaow44_
	.set	ssfaow44_,sgabeg+41204
	.globl	 ssfaow45_
	.set	ssfaow45_,sgabeg+41296
	.globl	 ssfaow46_
	.set	ssfaow46_,sgabeg+41388
	.globl	 ssfaow47_
	.set	ssfaow47_,sgabeg+41480
	.globl	 ssfaow48_
	.set	ssfaow48_,sgabeg+41572
	.globl	 ssfaow49_
	.set	ssfaow49_,sgabeg+41664
	.globl	 ssfaow50_
	.set	ssfaow50_,sgabeg+41756
	.globl	 kviilt_
	.set	kviilt_,sgabeg+41848
	.globl	 kvislt_
	.set	kvislt_,sgabeg+41852
	.globl	 kvitlt_
	.set	kvitlt_,sgabeg+41856
	.globl	 kviidl_
	.set	kviidl_,sgabeg+41860
	.globl	 kvisdl_
	.set	kvisdl_,sgabeg+41864
	.globl	 kvitdl_
	.set	kvitdl_,sgabeg+41868
	.globl	 ksmsgl_
	.set	ksmsgl_,sgabeg+41872
