:
#
# $Header: getdbagp.sh@@/main/st_rdbms_7.3_CDM/pl_orainst_product_scrip \
#          ts_7.3.2/1 \
# Checked in on Wed Mar 13 12:52:07 PST 1996 by gbarskay \
# Copyright (c) 1995, 1996 by Oracle Corporation. All Rights Reserved. \
# $ Copyr (c) 1993 Oracle
#
echo `grep '#define SS_DBA_GRP' $ORACLE_HOME/rdbms/lib/config.s |    sed 's/#define SS_DBA_GRP \"//' | sed 's/\"$//'`
