rem 
rem $Header: oci24.sql,v 1.1 1995/03/05 23:43:56 vraghuna Exp $ 
rem 
Rem  Copyright (c) 1995 by Oracle Corporation 
Rem    NAME
Rem      oci24.sql 
Rem    DESCRIPTION
Rem	 Script for A22400 OCI Techniques White Paper
Rem      Demo script for oci24.c
Rem    MODIFIED   (MM/DD/YY)
Rem     vraghuna   03/01/95 -  Creation
set echo on;
connect internal;

REM
REM Create a new user - call it ocitest
REM
drop user ocitest cascade;
create user ocitest identified by ocitest;
grant connect, resource to ocitest;

REM
REM Created needed tables 
REM
connect ocitest/ocitest;

create table oci24tab (ename char(10), empno number, sal number);

create or replace package oci24pkg as

procedure oci24proc(
	name in oci24tab.ename%type,
	salary out oci24tab.sal%type);

procedure oci24proc(
	id_num in oci24tab.empno%type,
	salary out oci24tab.sal%type);

function oci24proc (
	name oci24tab.ename%type) return number;

end oci24pkg;

 
