rem 
rem $Header: oci12.sql,v 1.1 1995/03/05 23:29:18 vraghuna Exp $ 
rem 
Rem  Copyright (c) 1995 by Oracle Corporation 
Rem    NAME
Rem      oci12.sql
Rem    DESCRIPTION
Rem	 Script for A22400 OCI Techniques White Paper
Rem      Demo script for oci12.c
Rem    RETURNS
Rem 
Rem    NOTES
Rem      <other useful comments, qualifications, etc.>
Rem    MODIFIED   (MM/DD/YY)
Rem     vraghuna   03/01/95 -  Creation
 
set echo on;
connect internal;
drop user ocitest cascade;
create user ocitest identified by ocitest;
grant connect,resource to ocitest;
connect ocitest/ocitest;

create table oci12tab (col1 number, col2 long);
 
insert into oci12tab values(1,  'A');
insert into oci12tab values(2,  'AB');
insert into oci12tab values(3,  'ABC');
insert into oci12tab values(4,  'ABCDEFGHIJKLM');
insert into oci12tab values(5,  'ABCD');
insert into oci12tab values(6,  'ABCDE');
insert into oci12tab values(7,  'ABCDEFGHIJ');
insert into oci12tab values(8,  '1');
insert into oci12tab values(9,  '12');
insert into oci12tab values(10, '123');
insert into oci12tab values(11, '123456789');
insert into oci12tab values(12, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ');
commit;
