rem 
rem $Header: dbmssyer.sql,v 1.3 1994/03/29 16:32:14 adowning Exp $
rem 
Rem  Copyright (c) 1992 by Oracle Corporation 
Rem    NAME
Rem      dbmssyer.sql - DBMS_SYs_ErroR - pl/sql routines for 
Rem                     system error messages for DBMS* routines.
Rem    DESCRIPTION
Rem      This package is private.
Rem    RETURNS
Rem 
Rem    NOTES
Rem
Rem    MODIFIED   (MM/DD/YY)
Rem     adowning   03/29/94 -  merge changes from branch 1.1.710.2
Rem     adowning   02/02/94 -  split file into public / private binary files
Rem     dsdaniel   11/01/93 -  Branch_for_patch
Rem     dsdaniel   10/29/93 -  Creation
Rem
REM ********************************************************************
REM THESE PACKAGES MUST NOT BE MODIFIED BY THE CUSTOMER.  DOING SO
REM COULD CAUSE INTERNAL ERRORS AND SECURITY VIOLATIONS IN THE
REM RDBMS.  SPECIFICALLY, THE PSD*  ROUTINES MUST NOT BE
REM CALLED DIRECTLY BY ANY CLIENT AND MUST REMAIN PRIVATE TO THE PACKAGE BODY.
REM ********************************************************************

